_HUMAN_IMGT_V_CHAINS = None
_HUMAN_IMGT_J_CHAINS = None


def get_imgt_chain(gene_name):
    if gene_name.startswith('IGH'):
        chain_type = 'H'
    elif gene_name.startswith('IGK'):
        chain_type = 'K'
    elif gene_name.startswith('IGL'):
        chain_type = 'L'
    else:
        raise ValueError(f'Gene name should start with IG(H/K/L), got: {gene_name}')

    if gene_name.startswith(f'IG{chain_type}V'):
        chains = get_imgt_v_chains(chain_type)
    elif gene_name.startswith(f'IG{chain_type}J'):
        chains = get_imgt_j_chains(chain_type)
    else:
        raise ValueError(f'Expected V or J gene name, got: {gene_name}')

    if gene_name not in chains:
        suffixes = [chain_name for chain_name in chains if chain_name.startswith(gene_name)]
        if suffixes:
            raise ValueError(f'Gene name "{gene_name}" not complete, use one of: {suffixes}')
        print('Available gene names:', chains.keys())
        raise ValueError(f'Gene name "{gene_name}" not found')

    return chains[gene_name]


def get_imgt_v_chains(chain_type=None):
    global _HUMAN_IMGT_V_CHAINS
    if _HUMAN_IMGT_V_CHAINS is None:
        _HUMAN_IMGT_V_CHAINS = {}
        for t, germlines in HUMAN_IMGT_IG_V.items():
            positions = germlines['positions']
            seqs = germlines['aligned_sequences']
            _HUMAN_IMGT_V_CHAINS[t] = {name: germline_to_chain(positions, seq, name=name, chain_type=t) for name, seq in seqs.items()}
    return _HUMAN_IMGT_V_CHAINS[chain_type]


def get_imgt_j_chains(chain_type=None):
    global _HUMAN_IMGT_J_CHAINS
    if _HUMAN_IMGT_J_CHAINS is None:
        _HUMAN_IMGT_J_CHAINS = {}
        for t, germlines in HUMAN_IMGT_IG_J.items():
            positions = germlines['positions']
            seqs = germlines['aligned_sequences']
            _HUMAN_IMGT_J_CHAINS[t] = {name: germline_to_chain(positions, seq, name=name, chain_type=t) for name, seq in seqs.items()}
    return _HUMAN_IMGT_J_CHAINS[chain_type]


def germline_to_chain(positions, seq, chain_type, **kwargs):
    from abnumber.chain import Chain, Position
    return Chain(sequence=None, scheme='imgt', chain_type=chain_type, tail='', aa_dict={
        Position.from_string(pos, chain_type=chain_type, scheme='imgt'): aa for pos, aa in zip(positions, seq)
    }, **kwargs)


def get_germline_v_families(chain_type):
    names = HUMAN_IMGT_IG_V[chain_type]['aligned_sequences'].keys()
    return sorted(set([name.split('-')[0].split('/')[0] for name in names]))


def get_germline_v_genes(chain_type):
    names = HUMAN_IMGT_IG_V[chain_type]['aligned_sequences'].keys()
    return sorted(set([name.split('*')[0] for name in names]))


HUMAN_IMGT_IG_V = {
    'H': {
        "positions": [
            "H1", "H2", "H3", "H4", "H5", "H6", "H7", "H8", "H9", "H11", "H12", "H13", "H14", "H15", "H16", "H17", "H18", "H19", "H20", "H21", "H22", "H23", "H24", "H25", "H26", "H27", "H28", "H29", "H30", "H31", "H34", "H35", "H36", "H37", "H38", "H39", "H40", "H41", "H42", "H43", "H44", "H45", "H46", "H47", "H48", "H49", "H50", "H51", "H52", "H53", "H54", "H55", "H56", "H57", "H58", "H59", "H60", "H61", "H62", "H63", "H64", "H65", "H66", "H67", "H68", "H69", "H70", "H71", "H72", "H74", "H75", "H76", "H77", "H78", "H79", "H80", "H81", "H82", "H83", "H84", "H85", "H86", "H87", "H88", "H89", "H90", "H91", "H92", "H93", "H94", "H95", "H96", "H97", "H98", "H99", "H100", "H101", "H102", "H103", "H104", "H105", "H106", "H107"
        ],
        "aligned_sequences": {
            "IGHV1-18*01": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYGISWVRQAPGQGLEWMGWISAY--NGNTNYAQKLQGRVTMTTDTSTSTAYMELRSLRSDDTAVYYCAR-",
            "IGHV1-18*03": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYGISWVRQAPGQGLEWMGWISAY--NGNTNYAQKLQGRVTMTTDTSTSTAYMELRSLRSDDMAVYYCAR-",
            "IGHV1-18*04": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYGISWVRQAPGQGLEWMGWISAY--NGNTNYAQKLQGRVTMTTDTSTSTAYMELRSLRSDDTAVYYCAR-",
            "IGHV1-2*01": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TGYYMHWVRQAPGQGLEWMGRINPN--SGGTNYAQKFQGRVTSTRDTSISTAYMELSRLRSDDTVVYYCAR-",
            "IGHV1-2*02": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TGYYMHWVRQAPGQGLEWMGWINPN--SGGTNYAQKFQGRVTMTRDTSISTAYMELSRLRSDDTAVYYCAR-",
            "IGHV1-2*03": "QVQLVQSGAEVKKLGASVKVSCKASGYTF--TGYYMHWVXQAPGQGLEWMGWINPN--SGGTNYAQKFQGRVTMTRDTSISTAYMELSRLRSDDTAVYYCAR-",
            "IGHV1-2*04": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TGYYMHWVRQAPGQGLEWMGWINPN--SGGTNYAQKFQGWVTMTRDTSISTAYMELSRLRSDDTAVYYCAR-",
            "IGHV1-2*05": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TGYYMHWVRQAPGQGLEWMGRINPN--SGGTNYAQKFQGRVTMTRDTSISTAYMELSRLRSDDTVVYYCAR-",
            "IGHV1-2*06": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TGYYMHWVRQAPGQGLEWMGRINPN--SGGTNYAQKFQGRVTMTRDTSISTAYMELSRLRSDDTAVYYCAR-",
            "IGHV1-2*07": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TGYYMHWVRQAPGQGLEWMGWINPN--SGGTNYAHKFQGRVTMTRDTSISTAYMELSRLRSDDTAVYYCAR-",
            "IGHV1-24*01": "QVQLVQSGAEVKKPGASVKVSCKVSGYTL--TELSMHWVRQAPGKGLEWMGGFDPE--DGETIYAQKFQGRVTMTEDTSTDTAYMELSSLRSEDTAVYYCAT-",
            "IGHV1-3*01": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYAMHWVRQAPGQRLEWMGWINAG--NGNTKYSQKFQGRVTITRDTSASTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-3*02": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYAMHWVRQAPGQRLEWMGWSNAG--NGNTKYSQEFQGRVTITRDTSASTAYMELSSLRSEDMAVYYCAR-",
            "IGHV1-3*03": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYAMHWVRQAPGQRLEWMGWINAG--NGNTKYSQEFQGRVTITRDTSASTAYMELSSLRSEDMAVYYCAR-",
            "IGHV1-3*05": "QVQLVQSGAEEKKPGASVKVSCKASGYTF--TSYAMHWVRQAPGQRLEWMGWINAG--NGNTKYSQKFQGRVTITRDTSASTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-38-4*01": "QVQLVQSWAEVRKSGASVKVSCSFSGFTI--TSYGIHWVQQSPGQGLEWMGWINPG--NGSPSYAKKFQGRFTMTRDMSTTTAYTDLSSLTSEDMAVYYYAR-",
            "IGHV1-45*01": "QMQLVQSGAEVKKTGSSVKVSCKASGYTF--TYRYLHWVRQAPGQALEWMGWITPF--NGNTNYAQKFQDRVTITRDRSMSTAYMELSSLRSEDTAMYYCAR-",
            "IGHV1-45*02": "QMQLVQSGAEVKKTGSSVKVSCKASGYTF--TYRYLHWVRQAPGQALEWMGWITPF--NGNTNYAQKFQDRVTITRDRSMSTAYMELSSLRSEDTAMYYCAR-",
            "IGHV1-45*03": "QMQLVQSGAEVKKTGSSVKVSCKASGYTF--TYRYLHWVRQAPRQALEWMGWITPF--NGNTNYAQKFQDRVTITRDRSMSTAYMELSSLRSEDTAMYYCAR-",
            "IGHV1-46*01": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYYMHWVRQAPGQGLEWMGIINPS--GGSTSYAQKFQGRVTMTRDTSTSTVYMELSSLRSEDTAVYYCAR-",
            "IGHV1-46*02": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--NSYYMHWVRQAPGQGLEWMGIINPS--GGSTSYAQKFQGRVTMTRDTSTSTVYMELSSLRSEDTAVYYCAR-",
            "IGHV1-46*03": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYYMHWVRQAPGQGLEWMGIINPS--GGSTSYAQKFQGRVTMTRDTSTSTVYMELSSLRSEDTAVYYCAR-",
            "IGHV1-46*04": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYYMHWVRQAPGQGLEWMGIINPS--GGSTSYAQKLQGRVTMTRDTSTSTVYMELSSLRSEDTAVYYCAR-",
            "IGHV1-58*01": "QMQLVQSGPEVKKPGTSVKVSCKASGFTF--TSSAVQWVRQARGQRLEWIGWIVVG--SGNTNYAQKFQERVTITRDMSTSTAYMELSSLRSEDTAVYYCAA-",
            "IGHV1-58*02": "QMQLVQSGPEVKKPGTSVKVSCKASGFTF--TSSAMQWVRQARGQRLEWIGWIVVG--SGNTNYAQKFQERVTITRDMSTSTAYMELSSLRSEDTAVYYCAA-",
            "IGHV1-68*01": "QVQLGQSEAEVKKPGASVKVSCKASGYTF--TCCSLHWLQQAPGQGLERMRWITLY--NGNTNYAKKFQGRVTITRDMSLRTAYIELSSLRSEDSAVYYWAR-",
            "IGHV1-68*02": "QVQLGQSEAEVKKPGASVKVSCKASGYTF--TYCSLHWLQQAPGQGLERMRWITLY--NGNINYAKKFQSRVTITRDMSLRTAYIELSSLRSEDSAVYYWAR-",
            "IGHV1-69*01": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGGIIPI--FGTANYAQKFQGRVTITADESTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*02": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYTISWVRQAPGQGLEWMGRIIPI--LGIANYAQKFQGRVTITADKSTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*04": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGRIIPI--LGIANYAQKFQGRVTITADKSTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*05": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGGIIPI--FGTANYAQKFQGRVTITTDESTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*06": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGGIIPI--FGTANYAQKFQGRVTITADKSTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*08": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYTISWVRQAPGQGLEWMGRIIPI--LGTANYAQKFQGRVTITADKSTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*09": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGRIIPI--LGIANYAQKFQGRVTITADKSTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*10": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGGIIPI--LGIANYAQKFQGRVTITADKSTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*11": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGRIIPI--LGTANYAQKFQGRVTITADESTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*12": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGGIIPI--FGTANYAQKFQGRVTITADESTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*13": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGGIIPI--FGTANYAQKFQGRVTITADESTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*14": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGGIIPI--FGTANYAQKFQGRVTITADKSTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*15": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGRIIPI--FGTANYAQKFQGRVTITADESTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*16": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYTISWVRQAPGQGLEWMGGIIPI--LGTANYAQKFQGRVTITTDESTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*17": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGGIIPI--FGIANYAQKFQGRVTITADKSTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69*19": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGGIIPI--FGTANYAQKFQGRVTITADESTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-69-2*01": "EVQLVQSGAEVKKPGATVKISCKVSGYTF--TDYYMHWVQQAPGKGLEWMGLVDPE--DGETIYAEKFQGRVTITADTSTDTAYMELSSLRSEDTAVYYCAT-",
            "IGHV1-69D*01": "QVQLVQSGAEVKKPGSSVKVSCKASGGTF--SSYAISWVRQAPGQGLEWMGGIIPI--FGTANYAQKFQGRVTITADESTSTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-8*01": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYDINWVRQATGQGLEWMGWMNPN--SGNTGYAQKFQGRVTMTRNTSISTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-8*02": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYDINWVRQATGQGLEWMGWMNPN--SGNTGYAQKFQGRVTMTRNTSISTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-8*03": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYDINWVRQATGQGLEWMGWMNPN--SGNTGYAQKFQGRVTITRNTSISTAYMELSSLRSEDTAVYYCAR-",
            "IGHV1-NL1*01": "QVQLLQPGVQVKKPGSSVKVSC-ASRYTF--TKYFTRWV-QSPGQGHXWMG-INPY--NDNTHYAQTFWGRVTITSDRSMSTAYMELSXLRSEDMVVYYCVR-",
            "IGHV1/OR15-1*01": "QVQLVQSGAEVKKPGASVKVSCKASGYIF--TDYYMHWVRQAPGQELGWMGRINPN--SGGTNYAQKFQGRVTMTRDTSISTAYTELSSLRSEDTATYYCAR-",
            "IGHV1/OR15-1*02": "QVQLVQSGAEVKKPGASVKVSCKASGYIF--TDYYMHWVRQAPGQELGWMGRINPN--SGGTNYAQKFQGRVTMTRDTSISTACTELSSLRSEDTATYYCAR-",
            "IGHV1/OR15-1*03": "QVQLVQSGAEVKKPGASVKVSCKASGYIF--TDYYMHWVRQAPGQELGWMGRINPN--SGGTNYAQKFQGRVTMTRDTSISTAYTELSSLRSEDTATYYCAR-",
            "IGHV1/OR15-1*04": "QVQLVQSGAEVKKPGASVKVSCKASGYIF--TDYYMHWVRQAPGQELGWMGRINPN--SGGTNYAQKFQGRVTMTRDTSISTAYMELSSLRSEDTATYYCAR-",
            "IGHV1/OR15-2*01": "QVQLVQSGAEVKKPRASVKVSCKASGYTF--TSYYMHWV-QAPEQGLEWMGWINTY--NGNTNYPQKLQGRVTMTRDTSTSTAYMELSRLRSDDMAVYYCAR-",
            "IGHV1/OR15-2*02": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TSYYMHWV-QAPEQGLEWMGWINTY--NGNTNYPQKLQGRVTMTRDTSTSTAYMELSSLRSDDMAVYYCAR-",
            "IGHV1/OR15-2*03": "QVQLVQSGAEVKKPRASVKVSCKASGYTF--TSYYMHWV-QAPEQGLEWMGWINTY--NGNTNYPQKLQGRVTMTRDTSTSTAYMELSSLRSDDMAVYYCAR-",
            "IGHV1/OR15-3*01": "QVQLV-SGAEVKKPGASVKVSCKASGYTF--TDYFMNWMRQAPGQRLEWMGWINAG--NGNTKYSQKLQGRVTITRDTSSSTAYMQLSSLRSEDTAVYYCAR-",
            "IGHV1/OR15-3*02": "QVQLV-SGAEVKKPGASVKVSCKASGYTF--TDYFMNWMRQAPGQRLEWMGWINAG--NGNTKYSQKLQGRVTITRDTSASTAYMQLSSLRSEDTAVYYCAR-",
            "IGHV1/OR15-3*03": "QVQLV-SGAEVKKPGASVKVSCKASGYTF--TSYYMNWMRQAPGQGFEWMGWINAG--NGNTKYSQKLQGRVTITRDTSASTAYMQLSSLRSEDTAVYYCAR-",
            "IGHV1/OR15-4*01": "QDQLVQSGAEVKKPLSSVKVSFKASGYTF--TNNFMHWV-QAPGQGLEWMGWINAG--NGNTTYAQKFQGRVTITRDTSMSTAYTELSSLRSEDTAVYYCAR-",
            "IGHV1/OR15-5*02": "QVQLVQSGAEVKKPGASVKVSCKASGYTF--TNYCMHWVRQVHAQGLEWMGLVCPS--DGSTSYAQKFQARVTITRDTSMSTAYMELSSLRSEDTAMYYCVR-",
            "IGHV1/OR15-9*01": "QVQLMQSGAEVKKPGASVRISCKASGYTF--TSYCMHWVCQAHAQGLEWMGLVCPS--DGSTSYAQKFQGRVTITRDTSMGTAYMELSSLRSEDTAMYYCVR-",
            "IGHV1/OR21-1*01": "QVQLVQSGAEVKKPGASVKVSCKASGYTI--TSYCMHWVHQVHAQGLEWMGLVCPS--DGSTSYAQKFQARVTITRDTSMSTAYMELSSLRSEDTAMYYCVR-",
            "IGHV2-10*01": "QVTLKESGPALVKPTQTLMLTCTFSGFSLSTSGMGVG-ICQPSAKALEWLAHIY-N---DNKYYSPSLKSRLIISKDTSKNEVVLTVINMDIVDTATHYCARR",
            "IGHV2-26*01": "QVTLKESGPVLVKPTETLTLTCTVSGFSLSNARMGVSWIRQPPGKALEWLAHIFSN---DEKSYSTSLKSRLTISKDTSKSQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-26*02": "QVTLKESGPVLVKPTETLTLTCTVSGFSLSNARMGVSWIRQPPGKALEWLAHIFSN---DEKSYSTSLKSRLTISKDTSKSQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-26*03": "QVTLKESGPVLVKPTETLTLTCTISGFSLSNARMGVSWIRQPPGKALEWLAHIFSN---DEKSYSTSLKSRLTISKDTSKSQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-5*01": "QITLKESGPTLVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIYWN---DDKRYSPSLKSRLTITKDTSKNQVVLTMTNMDPVDTATYYCAHR",
            "IGHV2-5*02": "QITLKESGPTLVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIYWD---DDKRYSPSLKSRLTITKDTSKNQVVLTMTNMDPVDTATYYCAHR",
            "IGHV2-5*05": "QITLKESGPTLVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIYWD---DDKRYGPSLKSRLTITKDTSKNQVVLTMTNMDPVDTATYYCAHR",
            "IGHV2-5*06": "QITLKESGPTLVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIYWD---DDKRYGPSLKSRLTITKDTSKNQVVLTMTNMDPVDTATYYCAHR",
            "IGHV2-5*08": "QVTLKESGPALVKPTQTLTLTCTFSGFSLSTSGMRVSWIRQPPGKALEWLALIYWD---DDKRYSPSLKSRLTITKDTSKNQVVLTMTNMDPVDTATYYCAHR",
            "IGHV2-5*09": "QVTLKESGPTLVKPTQTLTLTCTFSGFSLSTSGVGVGWIRQPPGKALEWLALIYWD---DDKRYGPSLKSRLTITKDTSKNQVVLTMTNMDPVDTATYYCAHR",
            "IGHV2-70*01": "QVTLRESGPALVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLALIDWD---DDKYYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-70*04": "QVTLKESGPALVKPTQTLTLTCTFSGFSLSTSGMRVSWIRQPPGKALEWLARIDWD---DDKFYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-70*10": "QVTLKESGPALVKPTQTLTLTCTFSGFSLSTSGMRVSWIRQPPGKALEWIARIDWD---DDKYYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-70*11": "RVTLRESGPALVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLARIDWD---DDKYYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-70*12": "QITLKESGPTLVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLALIDWD---DDKYYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCAHR",
            "IGHV2-70*13": "QVTLRESGPALVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLALIDWD---DDKYYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-70*15": "QVTLRESGPALVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLARIDWD---DDKYYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-70*16": "QVTLKESGPVLVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLARIDWD---DDKFYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-70*17": "QVTLRESGPALVKPTQTLTLTCTFSGFSLSTSGMCVSWIRQPPGKALEWLARIDWD---DDKFYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-70*18": "QVTLRESGPALVKPTQTLTLTCTFSGFSLSTSEMCVSWVRQPPGKALEWLALIDWD---DDKYYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-70*19": "QVTLRESGPALVKPTQTLTLTCTFSGFSLSTSGMCVSWVRQPPGKALEWLALIDWD---DDKHYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-70D*04": "QVTLKESGPALVKPTQTLTLTCTFSGFSLSTSGMRVSWIRQPPGKALEWLARIDWD---DDKFYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARI",
            "IGHV2-70D*14": "QVTLKESGPALVKPTQTLTLTCTFSGFSLSTSGMRVSWIRQPPGKALEWLARIDWD---DDKFYSTSLKTRLTISKDTSKNQVVLTMTNMDPVDTATYYCARI",
            "IGHV2/OR16-5*01": "QVTLKESGPALVKPTETLTLTCTLSGFSLSTSGMGMSWIRQPPGKALEWLAHIFLN---DKKSYSTSLKNRLIISKDTSKSQVVLTMTNMDPVDTATYYCAWR",
            "IGHV3-11*01": "QVQLVESGGGLVKPGGSLRLSCAASGFTF--SDYYMSWIRQAPGKGLEWVSYISSS--GSTIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-11*03": "QVQLLESGGGLVKPGGSLRLSCAASGFTF--SDYYMSWIRQAPGKGLEWVSYISSS--SSYTNYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-11*04": "QVQLVESGGGLVKPGGSLRLSCAASGFTF--SDYYMSWIRQAPGKGLEWVSYISSS--GSTIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-11*05": "QVQLVESGGGLVKPGGSLRLSCAASGFTF--SDYYMSWIRQAPGKGLEWVSYISSS--SSYTNYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-11*06": "QVQLVESGGGLVKPGGSLRLSCAASGFTF--SDYYMSWIRQAPGKGLEWVSYISSS--SSYTNYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-13*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYDMHWVRQATGKGLEWVSAIGTA---GDTYYPGSVKGRFTISRENAKNSLYLQMNSLRAGDTAVYYCAR-",
            "IGHV3-13*02": "EVHLVESGGGLVQPGGALRLSCAASGFTF--SNYDMHWVRQATGKGLEWVSANGTA---GDTYYPGSVKGRFTISRENAKNSLYLQMNSLRAGDTAVYYCAR-",
            "IGHV3-13*03": "EVQLVESGGGLVQPGGSLRLSCAACGFTF--SSYDMHWVRQATGKGLEWVSAIGTA---GDTYYPGSVKGQFTISRENAKNSLYLQMNSLRAGDTAVYYCAR-",
            "IGHV3-13*04": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYDMHWVRQATGKGLEWVSAIGTA---GDTYYPGSVKGRFTISRENAKNSLYLQMNSLRAGDTAVYYCAR-",
            "IGHV3-13*05": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYDMHWVRQATGKGLEWVSAIGTA---GDPYYPGSVKGRFTISRENAKNSLYLQMNSLRAGDTAVYYCAR-",
            "IGHV3-15*01": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SNAWMSWVRQAPGKGLEWVGRIKSKTDGGTTDYAAPVKGRFTISRDDSKNTLYLQMNSLKTEDTAVYYCTT-",
            "IGHV3-15*02": "EVQLVESGGALVKPGGSLRLSCAASGFTF--SNAWMSWVRQAPGKGLEWVGRIKSKTDGGTTDYAAPVKGRFTISRDDSKNTLYLQMNSLKTEDTAVYYCTT-",
            "IGHV3-15*03": "EVQLVESAGALVQPGGSLRLSCAASGFTC--SNAWMSWVRQAPGKGLEWVGRIKSKANGGTTDYAAPVKGRFTISRVDSKNTLYLQMNSLKTEDTAVYYCTT-",
            "IGHV3-15*04": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SNAWMSWVRQAPGKGLEWVGRIESKTDGGTTDYAAPVKGRFTISRDDSKNTLYLQMNSLKTEDTAVYYCTT-",
            "IGHV3-15*05": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SNAWMSWVRQAPGKGLEWVGRIKSKTDGGTTDYAAPVKGRFTISRDDSKNTLYLQMNSLKTEDTAVYYCTT-",
            "IGHV3-15*06": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SNAWMSWVRQAPGKGLEWVGRIKSKTDGGTTNYAAPVKGRFTISRDDSKNTLYLQMNSLKTEDTAVYYCTT-",
            "IGHV3-15*07": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SNAWMNWVRQAPGKGLEWVGRIKSKTDGGTTDYAAPVKGRFTISRDDSKNTLYLQMNSLKTEDTAVYYCTT-",
            "IGHV3-15*08": "EVQLVESAGGLVQPGGSLRLSCAASGFTC--SNAWMSWVRQAPGKGLEWVGCIKSKANGGTTDYAAPVKGRFTISRDDSKNTLYLQMISLKTEDTAVYYCTT-",
            "IGHV3-16*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SNSDMNWARKAPGKGLEWVSGVSWN--GSRTHYVDSVKRRFIISRDNSRNSLYLQKNRRRAEDMAVYYCVR-",
            "IGHV3-16*02": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SNSDMNWARKAPGKGLEWVSGVSWN--GSRTHYVDSVKRRFIISRDNSRNSLYLQKNRRRAEDMAVYYCVR-",
            "IGHV3-19*01": "TVQLVESGGGLVEPGGSLRLSCAASGFTF--SNSDMNWVRQAPGKGLEWVSGVSWN--GSRTHYADSVKGRFIISRDNSRNFLYQQMNSLRPEDMAVYYCVR-",
            "IGHV3-20*01": "EVQLVESGGGVVRPGGSLRLSCAASGFTF--DDYGMSWVRQAPGKGLEWVSGINWN--GGSTGYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTALYHCAR-",
            "IGHV3-20*02": "EVQLVESGGGVVRPGGSLRLSFAASGFTF--DDYGMSWVRQAPGKGLEWVSGINWN--GGSTGYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTALYHCAR-",
            "IGHV3-20*03": "EVQLVESGGGVVRPGGSLRLSFAASGFTF--DDYGMSWVRQAPGKGLEWVSGINWN--GGSTGYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTALYYCAR-",
            "IGHV3-20*04": "EVQLVESGGGVVRPGGSLRLSCAASGFTF--DDYGMSWVRQAPGKGLEWVSGINWN--GGSTGYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTALYYCAR-",
            "IGHV3-21*01": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SSYSMNWVRQAPGKGLEWVSSISSS--SSYIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-21*02": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SSYSMNWVRQAPGKGLEWVSSISSS--SSYIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-21*03": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SSYSMNWVRQAPGKGLEWVSSISSS--SSYIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-21*04": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SSYSMNWVRQAPGKGLEWVSSISSS--SSYIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-21*05": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SSYSMNWVRQAPGKGLEWVSYISSS--SSYIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-21*06": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SSYSMNWVRQAPGKGLEWVSSISSS--SSYIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-22*01": "EVHLVESGGALVQPGGSLRLSCAASGFTF--SYYYMSGVRQAPGKGLEWVGFIRNKANGGTTE-TTSVKGRFTISRDDSKSITYLQMKSLKTEDTAVYYCSR-",
            "IGHV3-22*02": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SYYYMSGVRQAPGKGLEWVGFIRNKANGGTTE-TTSVKGRFTISRDDSKSITYLQMKSLKTEDTAVYYCSR-",
            "IGHV3-23*01": "EVQLLESGGGLVQPGGSLRLSCAASGFTF--SSYAMSWVRQAPGKGLEWVSAISGS--GGSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3-23*02": "EVQLLESGGGLVQPGGSLRLSCAASGFTF--SSYAMSWVRQAPGKGLEWVSAISGS--GGSTYYGDSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3-23*03": "EVQLLESGGGLVQPGGSLRLSCAASGFTF--SSYAMSWVRQAPGKGLEWVSVIYSG--GSSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3-23*04": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYAMSWVRQAPGKGLEWVSAISGS--GGSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3-23D*01": "EVQLLESGGGLVQPGGSLRLSCAASGFTF--SSYAMSWVRQAPGKGLEWVSAISGS--GGSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3-25*01": "EMQLVESGGGLQKPAWSPRLSCAASQFTF--SSYYMNCVRQAPGNGLELV-QVNPN--GGSTYLIDSGKDRFNTSRDNAKNTLHLQMNSLKTEDTALY-CTR-",
            "IGHV3-25*02": "EMQLVESGGGLAKPAWSPRLSCAASQFTF--SSYYMNCVRQAPGNGLELV-QVNPN--GGSTYLIDSGKDRFNTSRDNAKNTLHLQMNSLKTEDTALY-CTR-",
            "IGHV3-25*04": "ETQLVESGGGLAKPGRSPRLSCAASQFTF--SSYYMNCVRQAPGNGLELVGQVNPN--GGSTYLIDSGKDRFNTSRDNAKNTLHLQMNSLKTEDTALYYCTR-",
            "IGHV3-25*05": "EMQLVESGGGLAKPAWSPRLSCAASQFTF--SSYYMNCVRQAPGNGLELVGQVNPN--GGSTYLIDSGKDRFNTSRDNAKNTLHLQMNSLKTEDTALY-CTR-",
            "IGHV3-29*01": "EVELIEPTEDLRQPGKFLRLSCVASRFAF--SSF-MSPVHQSAGKGLE-VIDIKDD--GSQIHHADSVKGRFSISKDNAKNSLYLQMNSQRTEDMAVYGCT-G",
            "IGHV3-30*01": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*02": "QVQLVESGGGVVQPGGSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAFIRYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3-30*03": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*04": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*05": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEGTAVYYCAR-",
            "IGHV3-30*06": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*07": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*08": "QVQLVDSGGGVVQPGRSLRLSCAASAFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*09": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFAISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*10": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYTDSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*11": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*12": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*13": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNRLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*14": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*15": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMSSLRAEDTAVYYCAR-",
            "IGHV3-30*16": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*17": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30*18": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3-30*19": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30-2*01": "EVQLVESGEDPRQPGGSLRLSCADSGLTF--SSY-RNSVSQAPGKGLE-VVDIQCD--GSQICYA-SLKSKFTISKENAKNSLYLLMNSLRAAGTAVCYCM-G",
            "IGHV3-30-22*01": "EVELIESIEDLRQPGKFLRLSCVASRFAF--SSF-MSRVHQSPGKGLE-VIDIKDD--GSQIHHADSVKGRFSISKDNAKNSLYLQMNSQRAEDMDVYGCT-G",
            "IGHV3-30-3*01": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30-3*02": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3-30-3*03": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-30-33*01": "EVQLVESGEDPRQPGGSLRLSCADSGLTF--SSY-RSSVSQAPGKGLE-VVDIQCD--GSQICYA-SLKSKFTISKENAKNSLYLLMNSLRAEGTAVCYCM--",
            "IGHV3-30-42*01": "EVELIEPTEDLRQPGKFLRLSCVASRFAF--SSF-MSPVHQSAGKGLE-VIDIKDD--GSQIHHADSVKGRFSISKDNAKNSLYLQMNSQRTEDMAVYGCT-G",
            "IGHV3-30-5*01": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3-30-5*02": "QVQLVESGGGVVQPGGSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAFIRYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3-30-52*01": "EVQLVESGEDPRQPGGSLRLSCADSGLTF--SSY-RNSVSQAPGKGLE-VVDIQCD--GSQICYA-SLKSKFTISKENAKNSLYLLMNSLRAAGTAVCYCM--",
            "IGHV3-32*01": "EVELIESIEDLRQPGKFLRLSCVASRFAF--SSF-MSRVHQSPGKGLE-VIDIKDD--GSQIHHADSVKGRFSISKDNAKNSLYLQMNTQRAEDVAVYGYT-G",
            "IGHV3-33*01": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVIWYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-33*02": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVIWYD--GSNKYYADSAKGRFTISRDNSTNTLFLQMNSLRAEDTAVYYCAR-",
            "IGHV3-33*03": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVIWYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3-33*04": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVIWYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-33*05": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVISYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-33*06": "QVQLVESGGGVVQPGRSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVAVIWYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3-33*07": "QVQLVESGGRVVQPGRSLRLSCAASGFTF--SRYGMYWVRQAPGKGLEWVAVIWYD--GSNKYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-33-2*01": "EVQLVESGEDPRQPGGSLRLSCADSGLTF--SSY-MSSVSQAPGKGLE-VVDIQCD--GSQICYAQSVKSKFTISKENAKNSLYLQMNSLRAEGTAVCYCM-G",
            "IGHV3-35*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SNSDMNWVHQAPGKGLEWVSGVSWN--GSRTHYADSVKGRFIISRDNSRNTLYLQTNSLRAEDTAVYYCVR-",
            "IGHV3-38*01": "EVQLVESGGGLVQPRGSLRLSCAASGFTV--SSNEMSWIRQAPGKGLEWVSSISG----GSTYYADSRKGRFTISRDNSKNTLYLQMNNLRAEGTAAYYCARY",
            "IGHV3-38*02": "EVQLVESGGGLVQPRGSLRLSCAASGFTV--SSNEMSWIRQAPGKGLEWVSSISG----GSTYYADSRKGRFTISRDNSKNTLYLQMNNLRAEGTAVYYCARY",
            "IGHV3-38*03": "EVQLVESGGGLVQPRGSLRLSCAASGFTV--SSNEMSWIRQAPGKGLEWVSSISG----GSTYYADSRKGRFTISRDNSKNTLYLQMNNLRAEGTAVYYCARY",
            "IGHV3-38-3*01": "EVQLVESRGVLVQPGGSLRLSCAASGFTV--SSNEMSWVRQAPGKGLEWVSSISG----GSTYYADSRKGRFTISRDNSKNTLHLQMNSLRAEDTAVYYCKK-",
            "IGHV3-41*02": "EVQLVESGGGLVQPGGSLRLSCAASGFSF--SSYGMSWVRQAPGKGLD-VAHIWND--GSQKYYADSVKGRFTISRDNSKSMLYLQMDSLKAKDTAMYYCTR-",
            "IGHV3-43*01": "EVQLVESGGVVVQPGGSLRLSCAASGFTF--DDYTMHWVRQAPGKGLEWVSLISWD--GGSTYYADSVKGRFTISRDNSKNSLYLQMNSLRTEDTALYYCAKD",
            "IGHV3-43*02": "EVQLVESGGGVVQPGGSLRLSCAASGFTF--DDYAMHWVRQAPGKGLEWVSLISGD--GGSTYYADSVKGRFTISRDNSKNSLYLQMNSLRTEDTALYYCAKD",
            "IGHV3-43D*03": "EVQLVESGGVVVQPGGSLRLSCAASGFTF--DDYAMHWVRQAPGKGLEWVSLISWD--GGSTYYADSVKGRFTISRDNSKNSLYLQMNSLRAEDTALYYCAKD",
            "IGHV3-43D*04": "EVQLVESGGVVVQPGGSLRLSCAASGFTF--DDYAMHWVRQAPGKGLEWVSLISWD--GGSTYYADSVKGRFTISRDNSKNSLYLQMNSLRAEDTALYYCAKD",
            "IGHV3-47*01": "EDQLVESGGGLVQPGGSLRPSCAASGFAF--SSYALHWVRRAPGKGLEWVSAIGTG---GDTYYADSVMGRFTISRDNAKKSLYLHMNSLIAEDMAVYYCAR-",
            "IGHV3-47*02": "EDQLVESGGGLVQPGGSLRPSCAASGFAF--SSYVLHWVRRAPGKGPEWVSAIGTG---GDTYYADSVMGRFTISRDNAKKSLYLQMNSLIAEDMAVYYCAR-",
            "IGHV3-48*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYSMNWVRQAPGKGLEWVSYISSS--SSTIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-48*02": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYSMNWVRQAPGKGLEWVSYISSS--SSTIYYADSVKGRFTISRDNAKNSLYLQMNSLRDEDTAVYYCAR-",
            "IGHV3-48*03": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYEMNWVRQAPGKGLEWVSYISSS--GSTIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-48*04": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYSMNWVRQAPGKGLEWVSYISSS--SSTIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-49*01": "EVQLVESGGGLVQPGRSLRLSCTASGFTF--GDYAMSWFRQAPGKGLEWVGFIRSKAYGGTTEYTASVKGRFTISRDGSKSIAYLQMNSLKTEDTAVYYCTR-",
            "IGHV3-49*02": "EVQLVESGGGLVQPGPSLRLSCTASGFTF--GYYPMSWVRQAPGKGLEWVGFIRSKAYGGTTEYAASVKGRFTISRDDSKSIAYLQMNSLKTEDTAVYYCTR-",
            "IGHV3-49*03": "EVQLVESGGGLVQPGRSLRLSCTASGFTF--GDYAMSWFRQAPGKGLEWVGFIRSKAYGGTTEYAASVKGRFTISRDDSKSIAYLQMNSLKTEDTAVYYCTR-",
            "IGHV3-49*04": "EVQLVESGGGLVQPGRSLRLSCTASGFTF--GDYAMSWVRQAPGKGLEWVGFIRSKAYGGTTEYAASVKGRFTISRDDSKSIAYLQMNSLKTEDTAVYYCTR-",
            "IGHV3-49*05": "EVQLVESGGGLVKPGRSLRLSCTASGFTF--GDYAMSWFRQAPGKGLEWVGFIRSKAYGGTTEYAASVKGRFTISRDDSKSIAYLQMNSLKTEDTAVYYCTR-",
            "IGHV3-52*01": "EVQLVESG-GLVQPGGSLRLSCAASGFTF--SSSWMHWVCQAPEKGLEWVADIKCD--GSEKYYVDSVKGRLTISRDNAKNSLYLQVNSLRAEDMTVYYCVR-",
            "IGHV3-52*03": "EVQLVESG-GLVQPGGSLRLSCAASGFTF--SSSWMHWVCQAPEKGLEWVADIKCD--GSEKYYVDSVKGRLTISRDNAKNSLYLQVNSLRAEDMTVYYCVR-",
            "IGHV3-53*01": "EVQLVESGGGLIQPGGSLRLSCAASGFTV--SSNYMSWVRQAPGKGLEWVSVIYSG---GSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-53*02": "EVQLVETGGGLIQPGGSLRLSCAASGFTV--SSNYMSWVRQAPGKGLEWVSVIYSG---GSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-53*03": "EVQLVESGGGLIQPGGSLRLSCAASGFTV--SSNYMSWVRQPPGKGLEWVSVIYSG---GSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-53*04": "EVQLVESGGGLVQPGGSLRLSCAASGFTV--SSNYMSWVRQAPGKGLEWVSVIYSG---GSTYYADSVKGRFTISRHNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-53*05": "EVQLVETGGGLIQPGGSLRLSCAASGFTV--SSNYMSWVRQAPGKGLEWVSVIYSG---GSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-54*01": "EVQLVESEENQRQLGGSLRLSCADSGLTF--SSY-MSSDSQAPGKGLE-VVDI--D--RSQLCYAQSVKSRFTISKENAKNSLCLQMNSLRAEGTAVYYCM--",
            "IGHV3-54*02": "EVQLVESEENQRQLGGSLRLSCADSGLTF--SSY-MSSDSQAPGKGLE-VVDI-YD--RSQICYAQSVKSRFTISKENAKNSLRLQMNSLRAEGTAVYYCM--",
            "IGHV3-54*04": "EVQLVESEENQRQLGGSLRLSCADSGLTF--SSY-MSSDSQAPGKGLE-VVDI--D--RSQLCYAQSVKSRFTISKENAKNSLCLQMNSLRAEGTAVYYCM--",
            "IGHV3-62*01": "EVQLVESGEGLVQPGGSLRLSCAASGFTF--SSSAMHWVRQAPRKGL-WVSVISTS--GDTVLYTDSVKGRFTISRDNAQNSLSLQMNSLRAEGTVVYYCVK-",
            "IGHV3-62*03": "EVQLVESGEGLVQPGGSLRLSCAASGFTF--SSSAMHWVRQAPRKGL-WVSVISTS--GDTVLYTDSVKGRFTISRDNAQNSLYLQMNSLRADDMAVYYCVK-",
            "IGHV3-62*04": "EVQLVKSGGGLVQPGGSLRLSCAASGFTF--SSSAMHWVRQAPRKGLEWVSVISTS--GDTVLYTDSVKGRFTISRDNAQNSLSLQMNSLRAEDMAVYYCVK-",
            "IGHV3-63*01": "EVELIESIEGLRQLGKFLRLSCVASGFTF--SSY-MSWVNETLGKGLEGVIDVKYD--GSQIYHADSVKGRFTISKDNAKNSPYLQTNSLRAEDMTMHGCT-G",
            "IGHV3-64*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEYVSAISSN--GGSTYYANSVKGRFTISRDNSKNTLYLQMGSLRAEDMAVYYCAR-",
            "IGHV3-64*02": "EVQLVESGEGLVQPGGSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEYVSAISSN--GGSTYYADSVKGRFTISRDNSKNTLYLQMGSLRAEDMAVYYCAR-",
            "IGHV3-64*03": "EVQLVESGGGLVQPGGSLRLSCSASGFTF--SSYAMHWVRQAPGKGLEYVSAISSN--GGSTYYADSVKGRFTISRDNSKNTLYVQMSSLRAEDTAVYYCVK-",
            "IGHV3-64*04": "QVQLVESGGGLVQPGGSLRLSCSASGFTF--SSYAMHWVRQAPGKGLEYVSAISSN--GGSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-64*05": "EVQLVESGGGLVQPGGSLRLSCSASGFTF--SSYAMHWVRQAPGKGLEYVSAISSN--GGSTYYADSVKGRFTISRDNSKNTLYVQMSSLRAEDTAVYYCVK-",
            "IGHV3-64*07": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYAMHWVRQAPGKGLEYVSAISSN--GGSTYYADSVKGRFTISRDNSKNTLYLQMGSLRAEDMAVYYCAR-",
            "IGHV3-64D*06": "EVQLVESGGGLVQPGGSLRLSCSASGFTF--SSYAMHWVRQAPGKGLEYVSAISSN--GGSTYYADSVKGRFTISRDNSKNTLYLQMSSLRAEDTAVYYCVK-",
            "IGHV3-64D*08": "EVQLVESGGGLVQPGGSLRLSCSASGFTF--SSYAMHWVRQAPGKGLEYVSAISSN--GGSTYYADSVKGRFTISRDNSKNTLYLQMSSLRAEDTAVYYCVK-",
            "IGHV3-64D*09": "EVQLVESGGGLVQPGGSLRLSCSASGFTF--SSYAMHWVRQAPGKGLEYVSAISSN--GGSTYYADSVKGRFTISRDNSKNTLYLQMSSLRAEDTAVYYCVK-",
            "IGHV3-66*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTV--SSNYMSWVRQAPGKGLEWVSVIYSG---GSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-66*02": "EVQLVESGGGLVQPGGSLRLSCAASGFTV--SSNYMSWVRQAPGKGLEWVSVIYSG---GSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-66*03": "EVQLVESGGGLIQPGGSLRLSCAASGFTV--SSNYMSWVRQAPGKGLEWVSVIYSC---GSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-66*04": "EVQLVESGGGLVQPGGSLRLSCAASGFTV--SSNYMSWVRQAPGKGLEWVSVIYSG---GSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-69-1*01": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SDYYMNWVRQAPGKGLEWVSSISSS---STIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-69-1*02": "EVQLVESGGGLVKPGGSLRLSCAASGFTF--SDYYMNWVRQAPGKGLEWVSSISSS---STIYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-7*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYWMSWVRQAPGKGLEWVANIKQD--GSEKYYVDSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-7*02": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYWMSWVRQAPGKGLEWVANIKQD--GSEKYYVDSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-7*03": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYWMSWVRQAPGKGLEWVANIKQD--GSEKYYVDSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-7*04": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYWMSWVRQAPGKGLEWVANIKQD--GSEKYYVDSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-7*05": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYWMSWVRQAPGKGLEWVANIKQD--GSEKYYVDSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-71*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SDYYMSWVRQAPGKGLEWVGFIRNKANGGTTE-TTSVKGRFTISRDDSKSITYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-71*02": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SDYYMSWVRQAPGKGLEWVGFIRNKANGGTTE-TTSVKGRFTISRDDSKSITYLQMNSLRAEDMAVYYCAR-",
            "IGHV3-71*03": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SDYYMSWVRQAPGKGLEWVGFIRNKANGGTTE-TTSVKGRFTISRDDSKSITYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-71*04": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SDYYMSWVRQAPGKGLEWVGFIRNKANGGTTE-TTSVKGRFTISRDDSKSITYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-72*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SDHYMDWVRQAPGKGLEWVGRTRNKANSYTTEYAASVKGRFTISRDDSKNSLYLQMNSLKTEDTAVYYCAR-",
            "IGHV3-73*01": "EVQLVESGGGLVQPGGSLKLSCAASGFTF--SGSAMHWVRQASGKGLEWVGRIRSKANSYATAYAASVKGRFTISRDDSKNTAYLQMNSLKTEDTAVYYCTR-",
            "IGHV3-73*02": "EVQLVESGGGLVQPGGSLKLSCAASGFTF--SGSAMHWVRQASGKGLEWVGRIRSKANSYATAYAASVKGRFTISRDDSKNTAYLQMNSLKTEDTAVYYCTR-",
            "IGHV3-74*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYWMHWVRQAPGKGLVWVSRINSD--GSSTSYADSVKGRFTISRDNAKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-74*02": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYWMHWVRQAPGKGLVWVSRINSD--GSSTSYADSVKGRFTISRDNAKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-74*03": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYWMHWVRQAPGKGLVWVSRINSD--GSSTTYADSVKGRFTISRDNAKNTLYLQMNSLRAEDTAVYYCAR-",
            "IGHV3-9*01": "EVQLVESGGGLVQPGRSLRLSCAASGFTF--DDYAMHWVRQAPGKGLEWVSGISWN--SGSIGYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTALYYCAKD",
            "IGHV3-9*02": "EVQLVESGGGLVQPGRSLRLSCAASGFTS--DDYAMHWVRQAPGKGLEWVSGISWN--SGSIGYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTALYYCAKD",
            "IGHV3-9*03": "EVQLVESGGGLVQPGRSLRLSCAASGFTF--DDYAMHWVRQAPGKGLEWVSGISWN--SGSIGYADSVKGRFTISRDNAKNSLYLQMNSLRAEDMALYYCAKD",
            "IGHV3-NL1*01": "QVQLVESGGGVVQPGGSLRLSCAASGFTF--SSYGMHWVRQAPGKGLEWVSVIYSG--GSSTYYADSVKGRFTISRDNSKNTLYLQMNSLRAEDTAVYYCAK-",
            "IGHV3/OR15-7*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SDHYMSWVRQAQGKGLELVGLIRNKANSYTTEYAASVKGRLTISREDSKNTMYLQMSNLKTEDLAVYYCAR-",
            "IGHV3/OR15-7*02": "EVQLLESGGGLVQPGGSLRLSCAASGFTF--SDHYMSWVRQAQGKGLELVGLIRNKANSYTTEYAASVKGRLTISREDSKNTLYLQMSSLKTEDLAVYYCAR-",
            "IGHV3/OR15-7*03": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SDHYMSWVRQAQGKGLELVGLIRNKANSYTTEYAASVKGRLTISREDSKNTLYLQMSSLKTEDLAVYYCAR-",
            "IGHV3/OR15-7*05": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SDHYMSWVRQAQGKGLELVGLIRNKANSYTTEYAASVKGRLTISREDSKNTLYLQMSNLKTEDLAVYYCAR-",
            "IGHV3/OR16-10*01": "EVQLVQSGGGLVHPGGSLRLSCAGSGFTF--SSYAMHWVRQAPGKGLEWVSAIGTG---GGTYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDMAVYYCAR-",
            "IGHV3/OR16-10*02": "EVQLVQSGGGLVQPGGSLRLSCAGSGFTF--SSYAMHWVRQAPGKGLEWVSAIGTG---GGTYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDMAVYYCAR-",
            "IGHV3/OR16-10*03": "EVQLVESGGGLVQPGGSLRLSCAGSGFTF--SSYAMHWVRQAPGKGLEWVSAIGTG---GGTYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDMAVYYCAR-",
            "IGHV3/OR16-12*01": "EVQLVESGRGLAQPGGYLKLSGAASGFTV--GSWYMSWIHQAPGKGLEWVSYISSS--GCSTNYADSVKGRFTISTDNSKNTLYLQMNSLRVEDTAVYYCAR-",
            "IGHV3/OR16-13*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SSYWMHWVRQAPGKGLVWVSRINSD--GSSTSYADSMKGQFTISRDNAKNTLYLQMNSLRAEDMAVYYCTR-",
            "IGHV3/OR16-14*01": "EVQLEESGGGLVQPGGSLRLSCAASGFTF--SSYWMHWVRQSPGKGLV-VSRINSD--GSSTSYADSLKGQFTISRDNAKNTLYLQMNSLRAEDMAVYYCTR-",
            "IGHV3/OR16-15*01": "EVQLVESGGGLVQPGGSLRLSCAASVFTF--SNSDINWVL-APGKGLEWVSGISWN--GGKTHYVDSVKGQFSISRDNSSKSLYLQKNRQRAKDMAVYYCVR-",
            "IGHV3/OR16-15*02": "EVQLVESGGGLVQPGGSLRHSCAASGFTF--SNSDMNWVL-APGKGLEWVSGISWN--GGKTHYVDSVKGQFTISRDNSSKSLYLQKNRQRAKDMAVYYCVR-",
            "IGHV3/OR16-16*01": "EVQLVESGGGLVQPGGSLRHSCAASGFTF--SNSDMNWVL-APGKGLEWVSDISWN--GGKTHYVDSVKGQFTISRDNSSKSLYLQKNRQRAKDMAVYYCVR-",
            "IGHV3/OR16-17*01": "EVQLVESGGGLVQPGGSLRLSCPDSGFTF--SNHYMSWVRQAPGKGLEWISYISGD--SGYTNYADSVKGRFTISRDNANNSPYLQMNSLRAEDTAVYYCVK-",
            "IGHV3/OR16-18*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SNSDMNWVL-APGKGLEWVSGISWN--GGKTHYVDSVKGQFTISRDNSSKSLYLQKNRQRAKDMAVYYCVR-",
            "IGHV3/OR16-20*01": "EVQLVQSGGGLVQPGGSLRLSCAGSGFTF--SSYAMHWVRQAPGKGLEWVSAIGTG---GGTYYADSVKGRFTISRDNAKNSLYLQMNSLRAEDMAVYYCAR-",
            "IGHV3/OR16-6*02": "EVQLVESAGGLGTAWGSLRLSCAASGFTC--SNAWMSWVRQAPGKGLEWVGCIKSKANGGTTDYAAPVKGRFTISRDDSKNTLYLQMISLKTEDTAVYYCTT-",
            "IGHV3/OR16-8*01": "EVQLVESGGGLVQPGGSLRLSCPASGFTF--SNHYMSWVRQAPGKGLEWVSYISGD--SGYTNYADSVKGRFTISRDNANNSPYLQMNSLRAEDTAVYYCVK-",
            "IGHV3/OR16-8*02": "EVQLVESGGGLVQPGGSLRLSCPDSGFTF--SNHYMSWVRQAPGKGLEWISYISGD--SGYTNYADSVKGRFTISRDNANNSPYLQMNSLRAEDTAVYYCVK-",
            "IGHV3/OR16-9*01": "EVQLVESGGGLVQPGGSLRLSCAASGFTF--SNHYTSWVRQAPGKGLEWVSYSSGN--SGYTNYADSVKGRFTISRDNAKNSLYLQMNSLRAEDTAVYYCVK-",
            "IGHV4-28*01": "QVQLQESGPGLVKPSDTLSLTCAVSGYSIS-SSNWWGWIRQPPGKGLEWIGYIYYS---GSTYYNPSLKSRVTMSVDTSKNQFSLKLSSVTAVDTAVYYCAR-",
            "IGHV4-28*02": "QVQLQESGPGLVKPSQTLSLTCAVSGYSIS-SSNWWGWIRQPPGKGLEWIGYIYYS---GSIYYNPSLKSRVTMSVDTSKNQFSLKLSSVTAVDTAVYYCAR-",
            "IGHV4-28*03": "QVQLQESGPGLVKPSDTLSLTCAVSGYSIS-SSNWWGWIRQPPGKGLEWIGYIYYS---GSTYYNPSLKSRVTMSVDTSKNQFSLKLSSVTAVDTAVYYCAR-",
            "IGHV4-28*04": "QVQLQESGPGLVKPSDTLSLTCAVSGYSIS-SSNWWGWIRQPPGKGLEWIGYIYYS---GSTYYNPSLKSRVTMSVDTSKNQFSLKLSSVTAVDTGVYYCAR-",
            "IGHV4-28*05": "QVQLQESGPGLVKPSDTLSLTCAVSGYSIS-SSNWWGWIRQPPGKGLEWIGYIYYS---GSIYYNPSLKSRVTMSVDTSKNQFSLKLSSVTAVDTAVYYCAR-",
            "IGHV4-28*06": "QVQLQESGPGLVKPSDTLSLTCAVSGYSIS-SSNWWGWIRQPPGKGLEWIGYIYYS---GSTNYNPSLKSRVTMSVDTSKNQFSLKLSSVTALDTAVYYCAR-",
            "IGHV4-28*07": "QVQLQESGPGLVKPSDTLSLTCAVSGYSIS-SSNWWGWIRQPPGKGLEWIGYIYYS---GSTYYNPSLKSRVTMSVDTSKNQFSLKLSSVTAVDTAVYYCAR-",
            "IGHV4-30-2*01": "QLQLQESGSGLVKPSQTLSLTCAVSGGSISSGGYSWSWIRQPPGKGLEWIGYIYHS---GSTYYNPSLKSRVTISVDRSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-30-2*03": "QLQLQESGSGLVKPSQTLSLTCAVSGGSISSGGYSWSWIRQPPGKGLEWIGSIYYS---GSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-30-2*05": "QLQLQESGSGLVKPSQTLSLTCAVSGGSISSGGYSWSWIRQPPGKGLEWIGYIYHS---GSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-30-2*06": "QLQLQESGSGLVKPSQTLSLTCAVSGGSISSGGYSWSWIRQSPGKGLEWIGYIYHS---GSTYYNPSLKSRVTISVDRSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-30-4*01": "QVQLQESGPGLVKPSQTLSLTCTVSGGSISSGDYYWSWIRQPPGKGLEWIGYIYYS---GSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-30-4*02": "QVQLQESGPGLVKPSDTLSLTCTVSGGSISSGDYYWSWIRQPPGKGLEWIGYIYYS---GSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-30-4*07": "QVQLQESGPGLVKPSQTLSLTCAVSGGSISSGGYSWSWIRQPPGKGLEWIGYIYYS---GSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-31*01": "QVQLQESGPGLVKPSQTLSLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGYIYYS---GSTYYNPSLKSLVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-31*02": "QVQLQESGPGLVKPSQTLSLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGYIYYS---GSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-31*03": "QVQLQESGPGLVKPSQTLSLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGYIYYS---GSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-31*10": "QVQLQESGPGLLKPSQTLSLTCTVSGGSISSGGYYWSWIRQHPGKGLEWIGCIYYS---GSTYYNPSLKSRVTISVDPSKNQFSLKPSSVTAADTAVDYCAR-",
            "IGHV4-34*01": "QVQLQQWGAGLLKPSETLSLTCAVYGGSF--SGYYWSWIRQPPGKGLEWIGEINHS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-34*02": "QVQLQQWGAGLLKPSETLSLTCAVYGGSF--SGYYWSWIRQPPGKGLEWIGEINHS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-34*04": "QVQLQQWGAGLLKPSETLSLTCAVYGGSF--SGYYWSWIRQPPGKGLEWIGEINHS---GSTNNNPSLKSRATISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-34*05": "QVQLQQWGAGLLKPSETLSLTCAVYGGSF--SGYYWCWIRQPLGKGLEWIGEINHS---GSTNNNPSLKSRATISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-34*09": "QVQLQESGPGLVKPSQTLSLTCAVYGGSF--SGYYWSWIRQPPGKGLEWIGEINHS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-34*10": "QVQLQESGPGLVKPSETLSLTCAVYGGSF--SGYYWSWIRQPPGKGLEWIGEINHS---GSTNYNPSLKSRITMSVDTSKNQFYLKLSSVTAADTAVYYCAR-",
            "IGHV4-34*11": "QVQLQQWGAGLLKPSETLSLTCAVYGGSV--SGYYWSWIRQPPGKGLEWIGYIYYS---GSTNNNPSLKSRATISVDTSKNQFSLNLSSVTAADTAVYCCAR-",
            "IGHV4-34*12": "QVQLQQWGAGLLKPSETLSLTCAVYGGSF--SGYYWSWIRQPPGKGLEWIGEIIHS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-38-2*01": "QVQLQESGPGLVKPSETLSLTCAVSGYSIS-SGYYWGWIRQPPGKGLEWIGSIYHS---GSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-38-2*02": "QVQLQESGPGLVKPSETLSLTCTVSGYSIS-SGYYWGWIRQPPGKGLEWIGSIYHS---GSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-39*01": "QLQLQESGPGLVKPSETLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYS---GSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-39*02": "QLQLQESGPGLVKPSETLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYS---GSTYYNPSLKSRVTISVDTSKNHFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-39*06": "RLQLQESGPGLVKPSETLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYS---GSTYYNPSLKSRVTISVDTSKNQFPLKLSSVTAADTAVYYCAR-",
            "IGHV4-39*07": "QLQLQESGPGLVKPSETLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGSIYYS---GSTYYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-4*01": "QVQLQESGPGLVKPPGTLSLTCAVSGGSIS-SSNWWSWVRQPPGKGLEWIGEIYHS---GSTNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYCCAR-",
            "IGHV4-4*02": "QVQLQESGPGLVKPSGTLSLTCAVSGGSIS-SSNWWSWVRQPPGKGLEWIGEIYHS---GSTNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-4*07": "QVQLQESGPGLVKPSETLSLTCTVSGGSI--SSYYWSWIRQPAGKGLEWIGRIYTS---GSTNYNPSLKSRVTMSVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-4*08": "QVQLQESGPGLVKPSETLSLTCTVSGGSI--SSYYWSWIRQPPGKGLEWIGYIYTS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-55*01": "QVQLQESGPGLVKPSETLSLICAVSGDSIS-SGNW-IWVRQPPGKGLEWIGEIHHS---GSTYYNPSLKSRITMSVDTSKNQFYLKLSSVTAADTAVYYCAR-",
            "IGHV4-55*02": "QVQLQESGPGLVKPSETLSLICAVSGDSIS-SGNW-IWVRQPPGKGLEWIGEIHHS---GSTYYNPSLKSRITMSVDTSKNQFYLKLSSVTAADTAVYYCAR-",
            "IGHV4-55*08": "QVQLQESGPGLVKPSETLSLICAVSGDSIS-SGNW-IWVRQPPGKGLEWIGEIHHS---GSTYYNPSLKSRITMSVDTSKNQFYLKLSSVTAADTAVYYCAR-",
            "IGHV4-55*09": "QVQLQESGPGLVKPSETLSLICAVSGDSIS-SGNW-IWVRQPPGKGLEWIGEIHHS---GSTYYNPSLKSRITMSVDTSKNQFSLKLSSVTAVDTAVYYCAR-",
            "IGHV4-59*01": "QVQLQESGPGLVKPSETLSLTCTVSGGSI--SSYYWSWIRQPPGKGLEWIGYIYYS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-59*02": "QVQLQESGPGLVKPSETLSLTCTVSGGSV--SSYYWSWIRQPPGKGLEWIGYIYYS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-59*07": "QVQLQESGPGLVKPSDTLSLTCTVSGGSI--SSYYWSWIRQPPGKGLEWIGYIYYS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-59*08": "QVQLQESGPGLVKPSETLSLTCTVSGGSI--SSYYWSWIRQPPGKGLEWIGYIYYS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-59*10": "QVQLQQWGAGLLKPSETLSLTCAVYGGSI--SSYYWSWIRQPAGKGLEWIGRIYTS---GSTNYNPSLKSRVTMSVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-59*11": "QVQLQESGPGLVKPSETLSLTCTVSGGSI--SSHYWSWIRQPPGKGLEWIGYIYYS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-59*13": "QVQLQESGPGLVKPSETLSLTCTVSGGSI--SSYYWSWIRQPPGKGLEWIGYIYYS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-61*01": "QVQLQESGPGLVKPSETLSLTCTVSGGSVSSGSYYWSWIRQPPGKGLEWIGYIYYS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-61*02": "QVQLQESGPGLVKPSQTLSLTCTVSGGSISSGSYYWSWIRQPAGKGLEWIGRIYTS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-61*03": "QVQLQESGPGLVKPSETLSLTCTVSGGSVSSGSYYWSWIRQPPGKGLEWIGYIYYS---GSTNYNPSLKSRVTISVDTSKNHFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-61*05": "QLQLQESGPGLVKPSETLSLTCTVSGGSISSSSYYWGWIRQPPGKGLEWIGYIYYS---GSTNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-61*08": "QVQLQESGPGLVKPSETLSLTCTVSGGSVSSGGYYWSWIRQPPGKGLEWIGYIYYS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4-61*09": "QVQLQESGPGLVKPSQTLSLTCTVSGGSISSGSYYWSWIRQPAGKGLEWIGHIYTS---GSTNYNPSLKSRVTISVDTSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4/OR15-8*01": "QVQLQESGPGLVKPSETLSLTCVVSGGSIS-SSNWWSWVRQPPGKGLEWIGEIYHS---GSPNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4/OR15-8*02": "QVQLQESGPGLVKPSETLSLTCVVSGGSIS-SSNWWSWVRQPPGKGLEWIGEIYHS---GNPNYNPSLKSRVTISIDKSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV4/OR15-8*03": "QVQLQESGPGLVKPSETLSLTCVVSGGSIS-SSNWWSWVRQPPGKGLEWIGEIYHS---GSPNYNPSLKSRVTISVDKSKNQFSLKLSSVTAADTAVYYCAR-",
            "IGHV5-10-1*01": "EVQLVQSGAEVKKPGESLRISCKGSGYSF--TSYWISWVRQMPGKGLEWMGRIDPS--DSYTNYSPSFQGHVTISADKSISTAYLQWSSLKASDTAMYYCAR-",
            "IGHV5-10-1*02": "EVQLVQSGAEVKKPGESLRISCKGSGYSF--TSYWISWVRQMPGKGLEWMGRIDPS--DSYTNYSPSFQGHVTISADKSISTAYLQWSSLKASDTAMYYCAR-",
            "IGHV5-10-1*03": "EVQLVQSGAEVKKPGESLRISCKGSGYSF--TSYWISWVRQMPGKGLEWMGRIDPS--DSYTNYSPSFQGHVTISADKSISTAYLQWSSLKASDTAMYYCAR-",
            "IGHV5-10-1*04": "EVQLVQSGAEVKKPGESLRISCKGSGYSF--TSYWISWVRQMPGKGLEWMGRIDPS--DSYTNYSPSFQGQVTISADKSISTAYLQWSSLKASDTAMYYCAR-",
            "IGHV5-51*01": "EVQLVQSGAEVKKPGESLKISCKGSGYSF--TSYWIGWVRQMPGKGLEWMGIIYPG--DSDTRYSPSFQGQVTISADKSISTAYLQWSSLKASDTAMYYCAR-",
            "IGHV5-51*02": "EVQLVQSGAEVKKPGESLKISCKGSGYSF--TSYWTGWVRQMPGKGLEWMGIIYPG--DSDTRYSPSFQGQVTISADKSISTAYLQWSSLKASDTAMYYCAR-",
            "IGHV5-51*03": "EVQLVQSGAEVKKPGESLKISCKGSGYSF--TSYWIGWVRQMPGKGLEWMGIIYPG--DSDTRYSPSFQGQVTISADKSISTAYLQWSSLKASDTAMYYCAR-",
            "IGHV5-51*04": "EVQLVQSGAEVKKPGESLKISCKGSGYSF--TSYWIGWVRQMPGKGLEWMGIIYPG--DSDTRYSPSFQGQVTISADKPISTAYLQWSSLKASDTAMYYCAR-",
            "IGHV5-51*07": "EVQLVQSGAEVKKPGESLKISCKGSGYSF--TSYWIGWVHQMPGKGLEWMGIIYPG--DSDTRYSPSFQGQVTISADKSISTAYLQWSSLKASDTAMYYCAR-",
            "IGHV5-78*01": "EVQLLQSAAEVKRPGESLRISCKTSGYSF--TSYWIHWVRQMPGKELEWMGSIYPG--NSDTRYSPSFQGHVTISADSSSSTAYLQWSSLKASDAAMYYCVR-",
            "IGHV6-1*01": "QVQLQQSGPGLVKPSQTLSLTCAISGDSVSSNSAAWNWIRQSPSRGLEWLGRTYYRS-KWYNDYAVSVKSRITINPDTSKNQFSLQLNSVTPEDTAVYYCAR-",
            "IGHV6-1*02": "QVQLQQSGPGLVKPSQTLSLTCAISGDSVSSNSAAWNWIRQSPSRGLEWLGRTYYRS-KWYNDYAVSVKSRITINPDTSKNQFSLQLNSVTPEDTAVYYCAR-",
            "IGHV6-1*03": "QVQLQQSGPGLVKPSQTLSLTCAISGDSVSSNSAAWNWIRQSPSRGLEWLGRTYYRS-KWYNDYAVSVKS-ITINPDTSKNQFSLQLNSVTPEDTAVYYCAR-",
            "IGHV7-34-1*01": "-LQLVQSGPEVKKPGASVKVSYKSSGYTF--TIYGMNWV--TPGQGFEWM-WIITY--TGNPTYTHGFTGWFVFSMDTSVSTACLQISSLKAEDTAEYYCAK-",
            "IGHV7-34-1*02": "-LQLVQSGPEVKKPGASVKVSYKSSGYTF--TIYGMNWV--TPGQGFEWM-WIITY--NGNPTYTHGFTGWFVFSMDTSVSTACLQISSLKAEDTAEYYCAK-",
            "IGHV7-34-1*03": "-LQLVQSGPEVKKRGASVKVSYKSSGYTF--TIYGMNWV--TPGQGFEWM-WIITY--TGNPTYTHGFTGWFVFSMDTSVSTACLQISSLKAEDTAEYYCAK-",
            "IGHV7-4-1*01": "QVQLVQSGSELKKPGASVKVSCKASGYTF--TSYAMNWVRQAPGQGLEWMGWINTN--TGNPTYAQGFTGRFVFSLDTSVSTAYLQICSLKAEDTAVYYCAR-",
            "IGHV7-4-1*02": "QVQLVQSGSELKKPGASVKVSCKASGYTF--TSYAMNWVRQAPGQGLEWMGWINTN--TGNPTYAQGFTGRFVFSLDTSVSTAYLQISSLKAEDTAVYYCAR-",
            "IGHV7-4-1*04": "QVQLVQSGSELKKPGASVKVSCKASGYTF--TSYAMNWVRQAPGQGLEWMGWINTN--TGNPTYAQGFTGRFVFSLDTSVSMAYLQISSLKAEDTAVYYCAR-",
            "IGHV7-4-1*05": "QVQLVQSGSELKKPGASVKVSCKASGYTF--TSYAMNWVRQAPGQGLEWMGWINTN--TGNPTYAQGFTGRFVFSLDTSVSMAYLQISSLKAEDTAVCYCAR-",
            "IGHV7-40*03": "FSIEKSNNLSVNQWMIR-NMIYVNHGILC--SQYGMNSV-PAPGQGLEWMGWIITY--TGNPTYTNGFTGRFLFSMDTSVSMAYLQISSLKAEDTAVYDCMR-",
            "IGHV7-81*01": "QVQLVQSGHEVKQPGASVKVSCKASGYSF--TTYGMNWVPQAPGQGLEWMGWFNTY--TGNPTYAQGFTGRFVFSMDTSASTAYLQISSLKAEDMAMYYCAR-",
            "IGHV8-51-1*01": "EAQLTESGGDLVH-EGPLRLSCAASWFTF--SIYEIHWVCQASGKGLEWVAVIWRS--ESHQYNADYVRGRLTTSRDNTKYMLYMQMNSLRTQNMAAFNCAG-",
            "IGHV8-51-1*02": "EAQLTESGGDLVHLEGPLRLSCAASWFTF--SIYEIHWVCQASGKGLEWVAVIWRG--ESHQYNADYVRGRLTTSRDNTKYMLYMQMISLRTQNMAAFNCAG-",
            "IGHV8-51-1*03": "EAQLTESGGDLVH-EGPLRLSCAASWFTF--SIYEIHWVCQASGKGLEWVAVIWRG--ESHQYNADYVRGRLTTSRDNTKYMLYMQMNSLRTQNMAAFNCAG-"
        }
    },
    'L': {
        "positions": [
            "L1", "L2", "L3", "L4", "L5", "L6", "L7", "L8", "L9", "L10", "L11", "L12", "L13", "L14", "L15", "L16", "L17", "L18", "L19", "L20", "L21", "L22", "L23", "L24", "L25", "L26", "L27", "L28", "L29", "L30", "L31", "L32", "L33", "L34", "L35", "L36", "L37", "L38", "L39", "L40", "L41", "L42", "L43", "L44", "L45", "L46", "L47", "L48", "L49", "L50", "L51", "L52", "L53", "L54", "L55", "L56", "L57", "L58", "L59", "L62", "L63", "L64", "L65", "L66", "L67", "L68", "L69", "L70", "L71", "L72", "L74", "L75", "L76", "L77", "L78", "L79", "L80", "L81", "L82", "L83", "L84", "L85", "L86", "L87", "L88", "L89", "L90", "L91", "L92", "L93", "L94", "L95", "L96", "L97", "L98", "L99", "L100", "L101", "L102", "L103", "L104", "L105", "L106", "L107", "L108", "L109", "L110", "L111", "L111A", "L111B", "L111C", "L111D"
        ],
        "aligned_sequences": {
            "IGLV1-36*01": "QSVLTQPPS-VSEAPRQRVTISCSGSSSNI----GNNAVNWYQQLPGKAPKLLIYYD-----DLLPSGVSDRFSGSK--SGTSASLAISGLQSEDEADYYCAAWDDSLNG--",
            "IGLV1-40*01": "QSVLTQPPS-VSGAPGQRVTISCTGSSSNIG---AGYDVHWYQQLPGTAPKLLIYGN-----SNRPSGVPDRFSGSK--SGTSASLAITGLQAEDEADYYCQSYDSSLSG--",
            "IGLV1-40*02": "QSVVTQPPS-VSGAPGQRVTISCTGSSSNIG---AGYDVHWYQQLPGTAPKLLIYGN-----SNRPSGVPDRFSGSK--SGTSASLAITGLQAEDEADYYCQSYDSSLSG--",
            "IGLV1-40*03": "QSVVTQPPS-VSGAPGQRVTISCTGSSSNIG---AGYDVHWYQQLPGTAPKLLIYGN-----SNRPSGVPDRFSGSK--SGASASLAITGLQAEDEADYYCQSYDSSLSG--",
            "IGLV1-41*01": "QSVLTQPPS-VSAAPGQKVTISCSGSSSDM----GNYAVSWYQQLPGTAPKLLIYEN-----NKRPSGIPDRFSGSK--SGTSATLGITGLWPEDEADYYCLAWDTSPRA--",
            "IGLV1-41*02": "QSVLTQPPS-VSAAPGQKVTISCSGSSSDM----GNYAVSWYQQLPGTAPKLLIYEN-----NKRPSGIPDRFSGSK--SGTSATLGITGLWPED-ADYYCLAWDTSLRA--",
            "IGLV1-44*01": "QSVLTQPPS-ASGTPGQRVTISCSGSSSNI----GSNTVNWYQQLPGTAPKLLIYSN-----NQRPSGVPDRFSGSK--SGTSASLAISGLQSEDEADYYCAAWDDSLNG--",
            "IGLV1-47*01": "QSVLTQPPS-ASGTPGQRVTISCSGSSSNI----GSNYVYWYQQLPGTAPKLLIYRN-----NQRPSGVPDRFSGSK--SGTSASLAISGLRSEDEADYYCAAWDDSLSG--",
            "IGLV1-47*02": "QSVLTQPPS-ASGTPGQRVTISCSGSSSNI----GSNYVYWYQQLPGTAPKLLIYSN-----NQRPSGVPDRFSGSK--SGTSASLAISGLRSEDEADYYCAAWDDSLSG--",
            "IGLV1-47*03": "QSVLTQPPS-ASGTPGQRVTISCSGSSSNI----GSNYVYWYQQLPGTAPKLLIYRN-----NQRPSGVPDRFSGSK--SGTSASLAISGLWSEDEADYYCAAWDDSLSG--",
            "IGLV1-50*01": "QSVLTQPPS-VSGAPGQRVTISCTGSSSNIG---AGYVVHWYQQLPGTAPKLLIYGN-----SNRPSGVPDQFSGSK--SGTSASLAITGLQSEDEADYYCKAWDNSLNA--",
            "IGLV1-51*01": "QSVLTQPPS-VSAAPGQKVTISCSGSSSNI----GNNYVSWYQQLPGTAPKLLIYDN-----NKRPSGIPDRFSGSK--SGTSATLGITGLQTGDEADYYCGTWDSSLSA--",
            "IGLV1-51*02": "QSVLTQPPS-VSAAPGQKVTISCSGSSSNI----GNNYVSWYQQLPGTAPKLLIYEN-----NKRPSGIPDRFSGSK--SGTSATLGITGLQTGDEADYYCGTWDSSLSA--",
            "IGLV1-62*01": "QSVLTQPPS-VSWATRQRLTVSCTGSSSNTG---TGYNVNCWQ-LPRTDPKLLRHGD-----KNWASWVSDQFSGSK--SGSLASLGTTGLWAEDKTDYHCQSRDIC-VL--",
            "IGLV10-54*01": "QAGLTQPPS-VSKGLRQTATLTCTGNSNNV----GNQGAAWLQQHQGHPPKLLSYRN-----NNRPSGISERLSASR--SGNTASLTITGLQPEDEADYYCSAWDSSLSA--",
            "IGLV10-54*02": "QAGLTQPPS-VSKGLRQTATLTCTGNSNIV----GNQGAAWLQQHQGHPPKLLSYRN-----NNRPSGISERFSASR--SGNTASLTITGLQPEDEADYYCSALDSSLSA--",
            "IGLV10-54*03": "QAGLTQPPS-VSKGLRQTATLTCTGNSNNV----GNQGAAWPEQHQGHPPKLLSYRN-----NNRPSGISERLSASR--SGNTASLTITGLQPEDEADYYCSAWDSSLSA--",
            "IGLV11-55*01": "RPVLTQPPS-LSASPGATARLPCTLSSDLSV---GGKNMFWYQQKPGSSPRLFLYHYSD-SDKQLGPGVPSRVSGSKETSSNTAFLLISGLQPEDEADYYCQVYESSAN---",
            "IGLV11-55*02": "RPVLTQPPS-LSASPGATARLPCTLSSDLSV---GGKNMFWYQQKLGSSPRLFLYHYSD-SDKQLGPGVPSRVSGSKETSSNTAFLLISGLQPEDEADYYCQVYESSAN---",
            "IGLV2-11*01": "QSALTQPRS-VSGSPGQSVTISCTGTSSDVG---GYNYVSWYQQHPGKAPKLMIYDV-----SKRPSGVPDRFSGSK--SGNTASLTISGLQAEDEADYYCCSYAGSYTF--",
            "IGLV2-11*02": "QSALTQPRS-VSGSPGQSVTISCTGTSSDVG---GYNYVSWYQQHPGKAPKLMIYDV-----SKRPSGVPDRFSGSK--SGNTASLTISGLQAEDEADYYCCSYAGSYTF--",
            "IGLV2-14*01": "QSALTQPAS-VSGSPGQSITISCTGTSSDVG---GYNYVSWYQQHPGKAPKLMIYEV-----SNRPSGVSNRFSGSK--SGNTASLTISGLQAEDEADYYCSSYTSSSTL--",
            "IGLV2-14*02": "QSALTQPAS-VSGSPGQSITISCTGTSSDVG---SYNLVSWYQQHPGKAPKLMIYEG-----SKRPSGVSNRFSGSK--SGNTASLTISGLQAEDEADYYCSSYTSSSTL--",
            "IGLV2-14*03": "QSALTQPAS-VSGSPGQSITISCTGTSSDVG---GYNYVSWYQQHPGKAPKLMIYDV-----SNRPSGVSNRFSGSK--SGNTASLTISGLQAEDEADYYCSSYTSSSTL--",
            "IGLV2-18*01": "QSALTQPPS-VSGSPGQSVTISCTGTSSDVG---SYNRVSWYQQPPGTAPKLMIYEV-----SNRPSGVPDRFSGSK--SGNTASLTISGLQAEDEADYYCSLYTSSSTF--",
            "IGLV2-18*02": "QSALTQPPS-VSGSPGQSVTISCTGTSSDVG---SYNRVSWYQQPPGTAPKLMIYEV-----SNRPSGVPDRFSGSK--SGNTASLTISGLQAEDEADYYCSSYTSSSTF--",
            "IGLV2-18*03": "QSALTQPPS-VSGSPGQSVTISCTGTSSDVG---SYNRVSWYQQPPGTAPKLMIYEV-----SNRPSGVPDRFSGSK--SGNTASLTTSGLQAEDEADYYCSSYTSSSTF--",
            "IGLV2-18*04": "QSALTQPPS-VSGSPGQSVTISCTGTSSDVG---SYNRVSWYQQPPGTAPKLMIYEV-----SNRPSGVPDRSSGSK--SGNTASLTISGLQAEDEADYYCSSYTSSSTF--",
            "IGLV2-23*01": "QSALTQPAS-VSGSPGQSITISCTGTSSDVG---SYNLVSWYQQHPGKAPKLMIYEG-----SKRPSGVSNRFSGSK--SGNTASLTISGLQAEDEADYYCCSYAGSSTL--",
            "IGLV2-23*02": "QSALTQPAS-VSGSPGQSITISCTGTSSDVG---SYNLVSWYQQHPGKAPKLMIYEV-----SKRPSGVSNRFSGSK--SGNTASLTISGLQAEDEADYYCCSYAGSSTF--",
            "IGLV2-23*03": "QSALTQPAS-VSGSPGQSITISCTGTSSDVG---SYNLVSWYQQHPGKAPKLMIYEG-----SKRPSGVSNRFSGSK--SGNTASLTISGLQAEDEADYYCCSYAGSSTF--",
            "IGLV2-33*01": "QSALTQPPF-VSGAPGQSVTISCTGTSSDVG---DYDHVFWYQKRLSTTSRLLIYNV-----NTRPSGISDLFSGSK--SGNMASLTISGLKSEVEANYHCSLYSSSYTF--",
            "IGLV2-33*02": "QSALTQPPF-VSGAPGQSVTISCTGTSSDVG---DYDHVFWYQKRLSTTSRLLIYNV-----NTRPSGISDLFSGSK--SGNMASLTISGLKSEVEANYHCSLYSSSYTF--",
            "IGLV2-33*03": "QSALTQPPF-VSGAPGQSVTISCTGTSSDVG---DYDHVFWYQKRLSTTSRLLIYNV-----NTRPSGISDLFSGSK--SGNVASLTISGLKSEVEANYHCSLYSSSYTF--",
            "IGLV2-34*01": "QSVLTQPRS-VSRSPGQ-VTIFCTGTSSDIG---GYDLVSWCQ-HPGKAPKLMIYDV-----ANWPSGAPGCFSGSK--SGNTASLTISGLQAEDEADYYCSSYAGSYNF--",
            "IGLV2-34*02": "QSVLTQPRS-VSRSPGQ-VTIFCTGTSSDIG---GYDLVSWCQ-HPGKAPKLMIYDV-----GNWPSGAPGCFSGSK--SGNTASLTISGLQAEDEADYYCSSYAGSYNF--",
            "IGLV2-5*01": "QSALIQPPS-VSGSPGQSVTISCTGTSSDVG---SYDYVSWYQQHPGTVPKPMIYNV-----NTQPSGVPDRFSGSK--SGNTASMTISGLQAEDEADY-CCSYTSSAT---",
            "IGLV2-5*02": "QSALIQPPS-VSGSPGQSVTISCTGTSSDVG---SYDYVSWYQQHPGTVPKPMIYNV-----NTRPSGVPDRFSGSK--SGNTASMTISGLQAEDEADY-CCSYTSSAT---",
            "IGLV2-8*01": "QSALTQPPS-ASGSPGQSVTISCTGTSSDVG---GYNYVSWYQQHPGKAPKLMIYEV-----SKRPSGVPDRFSGSK--SGNTASLTVSGLQAEDEADYYCSSYAGSNNF--",
            "IGLV2-8*02": "QSALTQPPS-ASRSPGQSVTISCTGTSSDVG---GYNYVSWYQQHPGKAPKLMIYEV-----SKRPSGVPDRFSGSK--SGNTASLTVSGLQAEDEADYYCSSYAGSNNF--",
            "IGLV3-1*01": "SYELTQPPS-VSVSPGQTASITCSGDKLG------DKYACWYQQKPGQSPVLVIYQD-----SKRPSGIPERFSGSN--SGNTATLTISGTQAMDEADYYCQAWDSSTA---",
            "IGLV3-10*01": "SYELTQPPS-VSVSPGQTARITCSGDALP------KKYAYWYQQKSGQAPVLVIYED-----SKRPSGIPERFSGSS--SGTMATLTISGAQVEDEADYYCYSTDSSGNH--",
            "IGLV3-10*03": "SYELTQPPS-VSVSPGQTARITCSGDALP------KKYAYWYQQKSGQAPVLVIYED-----SKRPSGIPERFSGSS--SGTMATLTISGAQVEDEDDYYCYSTDSSGNH--",
            "IGLV3-12*01": "SYELTQPHS-VSVATAQMARITCGGNNIG------SKAVHWYQQKPGQDPVLVIYSD-----SNRPSGIPERFSGSN--PGNTTTLTISRIEAGDEADYYCQVWDSSSDH--",
            "IGLV3-12*02": "SYELTQPHS-VSVATAQMARITCGGNNIG------SKAVHWYQQKPGQDPVLVIYSD-----SNRPSGIPERFSGSN--PGNTATLTISRIEAGDEADYYCQVWDSSSDH--",
            "IGLV3-13*01": "SYELTQPPA-VSVSPGQTARISCSGDVLR------DNYADWYPQKPGQAPVLVIYKD-----GERPSGIPERFSGST--SGNTTALTISRVLTKGGADYYCFSGD-NN----",
            "IGLV3-13*02": "SYELTQPPA-VSVSPGQTARISCSGDVLR------DNYADWYPQKPGQTPVLVIYKD-----GERPSGIPERFSGST--SGNTTALTISRVLTKGGADYYCFSGD-NN----",
            "IGLV3-16*01": "SYELTQPPS-VSVSLGQMARITCSGEALP------KKYAYWYQQKPGQFPVLVIYKD-----SERPSGIPERFSGSS--SGTIVTLTISGVQAEDEADYYCLSADSSGTY--",
            "IGLV3-19*01": "SSELTQDPA-VSVALGQTVRITCQGDSLR------SYYASWYQQKPGQAPVLVIYGK-----NNRPSGIPDRFSGSS--SGNTASLTITGAQAEDEADYYCNSRDSSGNH--",
            "IGLV3-19*02": "SSELTQDPA-VSVALGQTVRITCQGDSLR------SYYASWYQQKPGQAPVRVIYGK-----NNRPSGIPDRFSGSS--SGNTASLTITGAQAEDEADYYCNSWDSSGNH--",
            "IGLV3-21*01": "SYVLTQPPS-VSVAPGKTARITCGGNNIG------SKSVHWYQQKPGQAPVLVIYYD-----SDRPSGIPERFSGSN--SGNTATLTISRVEAGDEADYYCQVWDSSSDH--",
            "IGLV3-21*02": "SYVLTQPPS-VSVAPGQTARITCGGNNIG------SKSVHWYQQKPGQAPVLVVYDD-----SDRPSGIPERFSGSN--SGNTATLTISRVEAGDEADYYCQVWDSSSDH--",
            "IGLV3-21*03": "SYVLTQPPS-VSVAPGKTARITCGGNNIG------SKSVHWYQQKPGQAPVLVVYDD-----SDRPSGIPERFSGSN--SGNTATLTISRVEAGDEADYYCQVWDSSSDH--",
            "IGLV3-21*04": "SYVLTQPPS-VSVAPGKTARITCGGNNIG------SKSVHWYQQKPGQAPVLVIYYD-----SDRPSGIPERFSGSN--SGNTATLTISRVEAGDEADYYCQVWDSSSDH--",
            "IGLV3-22*01": "SYELTQLPS-VSVSPGQTARITCSGDVLG------ENYADWYQQKPGQAPELVIYED-----SERYPGIPERFSGST--SGNTTTLTISRVLTEDEADYYCLSGDEDN----",
            "IGLV3-22*03": "SYELTQLPS-VSLSPGQKARITCSGDVLG------KNYADWYQQKPGQAPELVIYED-----SERYPGIPERFSGST--SGNTTTLTISRVLTEDEADYYCLSGNEDN----",
            "IGLV3-25*01": "SYELMQPPS-VSVSPGQTARITCSGDALP------KQYAYWYQQKPGQAPVLVIYKD-----SERPSGIPERFSGSS--SGTTVTLTISGVQAEDEADYYCQSADSSGTY--",
            "IGLV3-25*02": "SYELTQPPS-VSVSPGQTARITCSGDALP------KQYAYWYQQKPGQAPVLVIYKD-----SERPSGIPERFSGSS--SGTTVTLTISGVQAEDEADYYCQSADSSGTY--",
            "IGLV3-25*03": "SYELTQPPS-VSVSPGQTARITCSGDALP------KQYAYWYQQKPGQAPVLVIYKD-----SERPSGIPERFSGSS--SGTTVTLTISGVQAEDEADYYCQSADSSGTY--",
            "IGLV3-27*01": "SYELTQPSS-VSVSPGQTARITCSGDVLA------KKYARWFQQKPGQAPVLVIYKD-----SERPSGIPERFSGSS--SGTTVTLTISGAQVEDEADYYCYSAADNN----",
            "IGLV3-31*01": "SSELSQEPA-VSVALG-TARITCQGDSIE------DSVVNWYKQKPSQAPGLVI-LN-----SVQSSGIPKKFSGSS--SGNMATLTITGIQVEDKADYYCQSWDSSRTH--",
            "IGLV3-31*02": "SSELSQEPA-VSVSLG-TARITCQGDSIE------DSVVNWYKQKPSQAPGLVI-LN-----SVQSSGIPKKFSGSS--SGNMATLTITGIQVEDKADYYCQSWDSSRTH--",
            "IGLV3-32*01": "SSGPTQVPA-VSVALGQMARITCQGDSME------GSYEHWYQQKPGQAPVLVIYDS-----SDRPSRIPERFSGSK--SGNTTTLTITGAQAEDEADYYYQLIDNHATQ--",
            "IGLV3-9*01": "SYELTQPLS-VSVALGQTARITCGGNNIG------SKNVHWYQQKPGQAPVLVIYRD-----SNRPSGIPERFSGSN--SGNTATLTISRAQAGDEADYYCQVWDSSTA---",
            "IGLV3-9*02": "SYELTQPLS-VSVALGQAARITCGGNNLG------YKSVHWYQQKPGQAPVLVIYRD-----NNRPSGIPERFSGSN--SGNTATLTISRAQAGDEADYYCQVWDSSTAH--",
            "IGLV4-3*01": "LPVLTQPPS-ASALLGASIKLTCTLSSEHS-----TYTIEWYQQRPGRSPQYIMKVKSD-GSHSKGDGIPDRFMGSS--SGADRYLTFSNLQSDDEAEYHCGESHTIDGQVG",
            "IGLV4-60*01": "QPVLTQSSS-ASASLGSSVKLTCTLSSGHS-----SYIIAWHQQQPGKAPRYLMKLEGS-GSYNKGSGVPDRFSGSS--SGADRYLTISNLQLEDEADYYCETWDSNT----",
            "IGLV4-60*02": "QPVLTQSSS-ASASLGSSVKLTCTLSSGHS-----SYIIAWHQQQPGKAPRYLMKLEGS-GSYNKGSGVPDRFSGSS--SGADRYLTISNLQFEDEADYYCETWDSNT----",
            "IGLV4-60*03": "QPVLTQSSS-ASASLGSSVKLTCTLSSGHS-----SYIIAWHQQQPGKAPRYLMKLEGS-GSYNKGSGVPDRFSGSS--SGADRYLTISNLQSEDEADYYCETWDSNT----",
            "IGLV4-69*01": "QLVLTQSPS-ASASLGASVKLTCTLSSGHS-----SYAIAWHQQQPEKGPRYLMKLNSD-GSHSKGDGIPDRFSGSS--SGAERYLTISSLQSEDEADYYCQTWGTGI----",
            "IGLV4-69*02": "QLVLTQSPS-ASASLGASVKLTCTLSSGHS-----SYAIAWHQQQPEKGPRYLMKLNSD-GSHSKGDGIPDRFSGSS--SGAERYLTISSLQSEDEADYYCQTWGTGI----",
            "IGLV5-37*01": "QPVLTQPPS-SSASPGESARLTCTLPSDINV---GSYNIYWYQQKPGSPPRYLLYYYSD-SDKGQGSGVPSRFSGSKDASANTGILLISGLQSEDEADYYCMIWPSNAS---",
            "IGLV5-39*01": "QPVLTQPTS-LSASPGASARFTCTLRSGINV---GTYRIYWYQQKPGSLPRYLLRYKSD-SDKQQGSGVPSRFSGSKDASTNAGLLLISGLQSEDEADYYCAIWYSSTS---",
            "IGLV5-39*02": "QPVLTQPTS-LSASPGASARFTCTLRSGINV---GTYRIYWYQQNPGSLPRYLLRYKSD-SDKQQGSGVPSRFSGSKDASTNAGLLLISGLQSEDEADYYCAIWYSSTS---",
            "IGLV5-45*01": "QAVLTQPAS-LSASPGASASLTCTLRSGINV---GTYRIYWYQQKPGSPPQYLLRYKSD-SDKQQGSGVPSRFSGSKDASANAGILLISGLQSEDEADYYCMIWHSSAS---",
            "IGLV5-45*02": "QAVLTQPSS-LSASPGASASLTCTLRSGINV---GTYRIYWYQQKPGSPPQYLLRYKSD-SDKQQGSGVPSRFSGSKDASANAGILLISGLQSEDEADYYCMIWHSSAS---",
            "IGLV5-45*03": "QAVLTQPSS-LSASPGASASLTCTLRSGINV---GTYRIYWYQQKPGSPPQYLLRYKSD-SDKQQGSGVPSRFSGSKDASANAGILLISGLQSEDEADYYCMIWHSSAS---",
            "IGLV5-45*04": "QAVLTQPSS-LSASPGASASLTCTLCSGINV---GTYRIYWYQQKPGSPPQYLLRYKSD-SDKQQGSGVPSRFSGSKDASANAGILLISGLQSEDEADYYCMIWHSSAS---",
            "IGLV5-48*01": "QPVLTQPTS-LSASPGASARLTCTLRSGINL---GSYRIFWYQQKPESPPRYLLSYYSD-SSKHQGSGVPSRFSGSKDASSNAGILVISGLQSEDEADYYCMIWHSSAS---",
            "IGLV5-48*02": "QAVLTQPTS-LSASPGASARLTCTLRSGISV---GSYRIYWYQQKPGSPPRYLLNYYSD-SDKHQGSGVPSRFSGSKDASTNAGILFISGL-SEDEADYYCMIWHSSAS---",
            "IGLV5-52*01": "QPVLTQPSS-HSASSGASVRLTCMLSSGFSV---GDFWIRWYQQKPGNPPRYLLYYHSD-SNKGQGSGVPSRFSGSNDASANAGILRISGLQPEDEADYYCGTWHSNSKT--",
            "IGLV6-57*01": "NFMLTQPHS-VSESPGKTVTISCTRSSGSI----ASNYVQWYQQRPGSSPTTVIYED-----NQRPSGVPDRFSGSIDSSSNSASLTISGLKTEDEADYYCQSYDSSN----",
            "IGLV6-57*02": "NFMLTQPHS-VSESPGKTVTISCTGSSGSI----ASNYVQWYQQRPGSAPTTVIYED-----NQRPSGVPDRFSGSIDSSSNSASLTISGLKTEDEADYYCQSYDSSN----",
            "IGLV6-57*03": "NFMLTQPHS-VSESPGKTVTISCTRSSGSI----ASNYVQWYQQRPGSAPTTVIYED-----NQRPSGVPDRFSGSIDSSSNSASLTISGLKTEDEADYYCQSYDSSN----",
            "IGLV7-43*01": "QTVVTQEPS-LTVSPGGTVTLTCASSTGAVT---SGYYPNWFQQKPGQAPRALIYST-----SNKHSWTPARFSGSL--LGGKAALTLSGVQPEDEAEYYCLLYYGGAQ---",
            "IGLV7-46*01": "QAVVTQEPS-LTVSPGGTVTLTCGSSTGAVT---SGHYPYWFQQKPGQAPRTLIYDT-----SNKHSWTPARFSGSL--LGGKAALTLSGAQPEDEAEYYCLLSYSGAR---",
            "IGLV7-46*02": "QAVVTQEPS-LTVSPGGTVTLTCGSSTGAVT---SGHYPYWFQQKPGQAPRTLIYDT-----SNKHSWTPARFSGSL--LGGKAALTLLGAQPEDEAEYYCLLSYSGAR---",
            "IGLV8-61*01": "QTVVTQEPS-FSVSPGGTVTLTCGLSSGSVS---TSYYPSWYQQTPGQAPRTLIYST-----NTRSSGVPDRFSGSI--LGNKAALTITGAQADDESDYYCVLYMGSGI---",
            "IGLV8-61*02": "QTVVTQEPS-FSVSPGGTVTLTCGLSSGSVS---TSYYPSWYQQTPGQAPRTLIYST-----NTRSSGVPDCFSGSI--LGNKAALTITGAQADDESDYYCVLYMGSGI---",
            "IGLV8/OR8-1*02": "QSVVTQEPS-LSGSPGGTVTLTCALSSGSVS---TSHYPRWYQQTPGQAPHMLICSP-----NTCPSGVPGRFSGSI--LGNKAALTITGTQVDDDSDHYCVLYMGSGN---",
            "IGLV9-49*01": "QPVLTQPPS-ASASLGASVTLTCTLSSGYS-----NYKVDWYQQRPGKGPRFVMRVGTGGIVGSKGDGIPDRFSVLG--SGLNRYLTIKNIQEEDESDYHCGADHGSGSNFV",
            "IGLV9-49*02": "QPVLTQPPS-ASASLGASVTLTCTLSSGYS-----NYKVDWYQQRPGKGPRFVMRVGTGGIVGSKGDGIPDRFSVLG--SGLNRYLTIKNIQEEDESDYHCGADHGSGSNFV",
            "IGLV9-49*03": "QPVLTQPPS-ASASLGASVTLTCTLSSGYS-----NYKVDWYQQRPGKGPRFVMRVGTGGIVGSKGDGIPDRFSVLG--SGLNRYLTIKNIQEEDESDYHCGADHGSGSNFV"
        }
    },
    'K': {
        "positions": [
            "L1", "L2", "L3", "L4", "L5", "L6", "L7", "L8", "L9", "L10", "L11", "L12", "L13", "L14", "L15", "L16", "L17", "L18", "L19", "L20", "L21", "L22", "L23", "L24", "L25", "L26", "L27", "L28", "L29", "L30", "L31", "L32", "L33", "L34", "L35", "L36", "L37", "L38", "L39", "L40", "L41", "L42", "L43", "L44", "L45", "L46", "L47", "L48", "L49", "L50", "L51", "L52", "L53", "L54", "L55", "L56", "L57", "L58", "L59", "L62", "L63", "L64", "L65", "L66", "L67", "L68", "L69", "L70", "L71", "L72", "L74", "L75", "L76", "L77", "L78", "L79", "L80", "L81", "L82", "L83", "L84", "L85", "L86", "L87", "L88", "L89", "L90", "L91", "L92", "L93", "L94", "L95", "L96", "L97", "L98", "L99", "L100", "L101", "L102", "L103", "L104", "L105", "L106", "L107", "L108", "L109", "L110", "L111", "L111A", "L111B", "L111C", "L111D"
        ],
        "aligned_sequences": {
          "IGKV1-12*01": "DIQMTQSPSSVSASVGDRVTITCRASQGI------SSWLAWYQQKPGKAPKLLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQANSFP----",
          "IGKV1-12*02": "DIQMTQSPSSVSASVGDRVTITCRASQGI------SSWLAWYQQKPGKAPKLLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQANSFP----",
          "IGKV1-13*01": "AIQLTQSPSSLSASVGDRVTITCRASQGI------SSALA-YQQKPGKAPKLLIYDA-----SSLESGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQFNNYP----",
          "IGKV1-13*02": "AIQLTQSPSSLSASVGDRVTITCRASQGI------SSALAWYQQKPGKAPKLLIYDA-----SSLESGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQFNSYP----",
          "IGKV1-16*01": "DIQMTQSPSSLSASVGDRVTITCRASQGI------SNYLAWFQQKPGKAPKSLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQYNSYP----",
          "IGKV1-16*02": "DIQMTQSPSSLSASVGDRVTITCRASQGI------SNYLAWFQQKPGKAPKSLIYAA-----SSLQSGVPSKFSGSG--SGTDFTLTISSLQPEDFATYYCQQYNSYP----",
          "IGKV1-17*01": "DIQMTQSPSSLSASVGDRVTITCRASQGI------RNDLGWYQQKPGKAPKRLIYAA-----SSLQSGVPSRFSGSG--SGTEFTLTISSLQPEDFATYYCLQHNSYP----",
          "IGKV1-17*02": "DIQMTQSPSSLSASVGDRVTITCRASQGI------RNDLGWYQQKPGKAPKRLIYAA-----SSLQSGVPSRFSGSG--SGTEFTLTISNLQPEDFATYYCLQHNSYP----",
          "IGKV1-17*03": "DIQMTQSPSAMSASVGDRVTITCRASQGI------SNYLAWFQQKPGKVPKRLIYAA-----SSLQSGVPSRFSGSG--SGTEFTLTISSLQPEDFATYYCLQHNSYP----",
          "IGKV1-27*01": "DIQMTQSPSSLSASVGDRVTITCRASQGI------SNYLAWYQQKPGKVPKLLIYAA-----STLQSGVPSRFSGSG--SGTDFTLTISSLQPEDVATYYCQKYNSAP----",
          "IGKV1-33*01": "DIQMTQSPSSLSASVGDRVTITCQASQDI------SNYLNWYQQKPGKAPKLLIYDA-----SNLETGVPSRFSGSG--SGTDFTFTISSLQPEDIATYYCQQYDNLP----",
          "IGKV1-37*01": "DIQLTQSPSSLSASVGDRVTITCRVSQGI------SSYLNWYRQKPGKVPKLLIYSA-----SNLQSGVPSRFSGSG--SGTDFTLTISSLQPEDVATYYGQRTYNAP----",
          "IGKV1-39*01": "DIQMTQSPSSLSASVGDRVTITCRASQSI------SSYLNWYQQKPGKAPKLLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQSYSTP----",
          "IGKV1-39*02": "DIQMTQSPSFLSASVGDRVTITCRASQSI------SSYLNWYQQKPGKAPKLLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQCGYSTP----",
          "IGKV1-5*01": "DIQMTQSPSTLSASVGDRVTITCRASQSI------SSWLAWYQQKPGKAPKLLIYDA-----SSLESGVPSRFSGSG--SGTEFTLTISSLQPDDFATYYCQQYNSYS----",
          "IGKV1-5*02": "DIQMTQSPSTLSASVGDRVTIICRASQSI------SSWLAWYQQKPGKAPKLLIYDA-----SSLESGVPSRFSGSG--SGTEFTLTISSLQPDDFATYYCQQYNSYS----",
          "IGKV1-5*03": "DIQMTQSPSTLSASVGDRVTITCRASQSI------SSWLAWYQQKPGKAPKLLIYKA-----SSLESGVPSRFSGSG--SGTEFTLTISSLQPDDFATYYCQQYNSYS----",
          "IGKV1-6*01": "AIQMTQSPSSLSASVGDRVTITCRASQGI------RNDLGWYQQKPGKAPKLLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCLQDYNYP----",
          "IGKV1-6*02": "AIQMTQSPSSLSASVGDRVTITCRASQGI------RNDLGWYQQKPGKAPKLLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCLQDYNYP----",
          "IGKV1-8*01": "AIRMTQSPSSFSASTGDRVTITCRASQGI------SSYLAWYQQKPGKAPKLLIYAA-----STLQSGVPSRFSGSG--SGTDFTLTISCLQSEDFATYYCQQYYSYP----",
          "IGKV1-9*01": "DIQLTQSPSFLSASVGDRVTITCRASQGI------SSYLAWYQQKPGKAPKLLIYAA-----STLQSGVPSRFSGSG--SGTEFTLTISSLQPEDFATYYCQQLNSYP----",
          "IGKV1-NL1*01": "DIQMTQSPSSLSASVGDRVTITCRASQGI------SNSLAWYQQKPGKAPKLLLYAA-----SRLESGVPSRFSGSG--SGTDYTLTISSLQPEDFATYYCQQYYSTP----",
          "IGKV1/OR-2*01": "DIQMTQSPSSLSASVGGRVTITCRASQGI------SNNLNWYQQKPRKTPKLLIYAA-----SSLQSGIPSRFSDSG--SGTDYTLTISSLQPEDFATYYCQQSDSNP----",
          "IGKV1/OR-3*01": "DIQMTQSPSSLSASVGGRVTITCRASQGI------SNNLNWYQQKPGKTPKLLIYAA-----SSLQSGIPSRFSDSG--SGTDYTLTISSLQPEDFAAYYCQQSDSTP----",
          "IGKV1/OR-4*01": "DIQMTQSPSSLSASVGDRVTITCRASQGI------SNNLNWYQQKPGKTPKFLIYAA-----SSLQSGIPSRFSDSG--SGTDYTLTISSLQPEDFATYYCQQSDSTP----",
          "IGKV1/OR1-1*01": "DIQMTQSPSSLSASVGDRVTITCRASQGI------SNNLNWYQQKPGKTPKLLIYAA-----SSLQSGIPSRFSDSG--SGADYTLTIRSLQPEDFATYYCQQSDSTP----",
          "IGKV1/OR10-1*01": "DIQMTQSPSSLSASVGDRVTITCRASQGI------SNNLNWYQQKPGKTPKLLIYAA-----SSLQSGIPSRFSDSG--SGTDYTLTISSLQPEDFATYYCQQSDSTS----",
          "IGKV1/OR15-118*01": "DIQMTQSPSSLSASVGDRVTITCRASQGI------SNNLNWYQQKPGKTPKLLIYAA-----PSLQSGIPSRFSDSG--SGADYTLTIRSLQPEDFATY-CQQSDSTP----",
          "IGKV1/OR2-0*01": "DIQMTQSPSSLSASVGDRVTITCRASQGI------SNNLNWYQQKPGKTPKLLIYAA-----PSLQSGIPSRFSDSG--SGADYTLTIRSLQPEDFATYYCQQSDSTP----",
          "IGKV1/OR2-1*01": "DIQMTQSPSSLSASVGGRVTITCRASQGI------SNNLNWYQQKPGKTPKLLIYAA-----SSLQSGIPSRFSDSG--SGADYTLTISSLQPEDFAAYYCQQSDSTP----",
          "IGKV1/OR2-108*01": "DIQVTQSPSSLSASVGDRVTITCRASQGI------SNGLSWYQQKPGQAPTLLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDVATYYCLQDYTTP----",
          "IGKV1/OR2-11*01": "DIQMTQPPSSLSASVGDRATVSCQASQSI------YNYLNWYQQKPGKAPKFLTYRA-----SSLQRAMPSQFSGSG--YGRDFTLTVSSLQPEDFATY-CQQESIFP----",
          "IGKV1/OR2-118*01": "DIQMTQSPSSLSASVGDRVTITCRASQGI------SNNLNWYQQKPGKTPKLLIYAA-----SSLQSGIPSRFSDSG--SGADYTLTIRSLQPEDFANYYCQQSDSTP----",
          "IGKV1/OR2-2*01": "DIQMTQSPSSLSASVGGRVTITCRASQGI------SNNLNWYQQKPGKTPKLLIYAA-----SSLQSGIPSRFSDSG--SGADYTLTISSLQPEDFAAYYCQQSDSTP----",
          "IGKV1/OR2-3*01": "DIQMTQPPSSLSASVGDRVTVSCQASQSI------YNYLNWYQQKPGKAPKFLTYRA-----SSLQRGMPSQFSGSG--YGRDFTLTVSSLQPEDFATY-CQQESIFP----",
          "IGKV1/OR2-9*01": "DIQMTQPPSSLSASVGDRATVSCQASQSI------YNYLNWYQQKPGKAPKFLTYRA-----SSLQRAMPSQFSGSG--YGRDFTLTVSSLQPEDFATY-CQQESIFP----",
          "IGKV1/OR22-5*01": "DIQMTQSPSSLSASVGGRVTITCRASQGI------SNNLNWYQQKPGKTPKPLIYAA-----SSLQSGIPSQFSDSG--SGTD-TLTISSLQPEDFATYYCQQSYSTP----",
          "IGKV1/OR22-5*02": "DIQMTQSPSSLSASVGDRVTITCRASQGI------SNNLNWYQQKPGKTPKLLIYAA-----SSLQSGIPSQFSDSG--SGTD-TLTISSLQPEDFTTYYCQQSYSTP----",
          "IGKV1/OR9-1*01": "DIQMTQSPSSLSASVGGRVTITCRVSQGI------SNNLNWYQQKPRKTPKLLIYAA-----SSLQSGIPSRFSDSG--SGTDYTLTISSLQPEDFATYYCQQSDSNP----",
          "IGKV1/OR9-2*01": "DIQMTQSPSSLSASVGGRVTITCRASQGI------SNNLNWYQQKPRKTPKLLIYAA-----SSLQSGIPSRFSDSG--SGTDYTLTISSLQPEDFATYYCQQSDSNP----",
          "IGKV1/ORY-1*01": "DIQMTQSPSSLSASVGDRVTITCRASQGI------INNLNWYQKKPGKTPKLLIYAA-----SSLQSGIPTRFSDSG--SGTDYTPTISSLQPEDFATYYCQQSDSTP----",
          "IGKV1D-12*01": "DIQMTQSPSSVSASVGDRVTITCRASQGI------SSWLAWYQQKPGKAPKLLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQANSFP----",
          "IGKV1D-12*02": "DIQMTQSPSSVSASVGDRVTITCRASQGI------SSWLAWYQQKPGKAPKLLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQANSFP----",
          "IGKV1D-13*01": "AIQLTQSPSSLSASVGDRVTITCRASQGI------SSALAWYQQKPGKAPKLLIYDA-----SSLESGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQFNNYP----",
          "IGKV1D-13*02": "AIQLTQSPSSLSASVGDRVTITCRASQGI------SSALAWYQQKPGKAPKLLIYDA-----SSLESGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQFNSYP----",
          "IGKV1D-16*01": "DIQMTQSPSSLSASVGDRVTITCRASQGI------SSWLAWYQQKPEKAPKSLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQYNSYP----",
          "IGKV1D-16*02": "DIQMTQSPSSLSASVGDRVTITCRARQGI------SSWLAWYQQKPEKAPKSLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQYNSYP----",
          "IGKV1D-17*01": "NIQMTQSPSAMSASVGDRVTITCRARQGI------SNYLAWFQQKPGKVPKHLIYAA-----SSLQSGVPSRFSGSG--SGTEFTLTISSLQPEDFATYYCLQHNSYP----",
          "IGKV1D-33*01": "DIQMTQSPSSLSASVGDRVTITCQASQDI------SNYLNWYQQKPGKAPKLLIYDA-----SNLETGVPSRFSGSG--SGTDFTFTISSLQPEDIATYYCQQYDNLP----",
          "IGKV1D-37*01": "DIQLTQSPSSLSASVGDRVTITCRVSQGI------SSYLNWYRQKPGKVPKLLIYSA-----SNLQSGVPSRFSGSG--SGTDFTLTISSLQPEDVATYYGQRTYNAP----",
          "IGKV1D-39*01": "DIQMTQSPSSLSASVGDRVTITCRASQSI------SSYLNWYQQKPGKAPKLLIYAA-----SSLQSGVPSRFSGSG--SGTDFTLTISSLQPEDFATYYCQQSYSTP----",
          "IGKV1D-42*01": "DIQMIQSPSFLSASVGDRVSIICWASEGI------SSNLAWYLQKPGKSPKLFLYDA-----KDLHPGVSSRFSGRG--SGTDFTLTIISLKPEDFAAYYCKQDFSYP----",
          "IGKV1D-42*02": "DIQMTQSPSFLSASVGDRVSIICWASEGI------SSNLAWYLQKPGKSPKLFLYDA-----KDLHPGVSSRFSGRG--SGTDFTLTIISLKPEDFAAYYCKQDFSYP----",
          "IGKV1D-43*01": "AIRMTQSPFSLSASVGDRVTITCWASQGI------SSYLAWYQQKPAKAPKLFIYYA-----SSLQSGVPSRFSGSG--SGTDYTLTISSLQPEDFATYYCQQYYSTP----",
          "IGKV1D-8*01": "VIWMTQSPSLLSASTGDRVTISCRMSQGI------SSYLAWYQQKPGKAPELLIYAA-----STLQSGVPSRFSGSG--SGTDFTLTISCLQSEDFATYYCQQYYSFP----",
          "IGKV1D-8*02": "AIWMTQSPSLLSASTGDRVTISCRMSQGI------SSYLAWYQQKPGKAPELLIYAA-----STLQSGVPSRFSGSG--SGTDFTLTISCLQSEDFATYYCQQYYSFP----",
          "IGKV1D-8*03": "VIWMTQSPSLLSASTGDRVTISCRMSQGI------SSYLAWYQQKPGKAPELLIYAA-----STLQSGVPSRFSGSG--SGTDFTLTISCLQSEDFATYYCQQYYSFP----",
          "IGKV2-18*01": "DIVMTQTPPSLPVNPGEPASISCRSSQSLLHS-NGYTYLHWYLQKPGQSPQLLIYRV-----SNHLSGVPDRFSGSG--SGSDFTLKISWVEAEDVGVYYCMQATQFP----",
          "IGKV2-24*01": "DIVMTQTPLSSPVTLGQPASISCRSSQSLVHS-DGNTYLSWLQQRPGQPPRLLIYKI-----SNRFSGVPDRFSGSG--AGTDFTLKISRVEAEDVGVYYCMQATQFP----",
          "IGKV2-28*01": "DIVMTQSPLSLPVTPGEPASISCRSSQSLLHS-NGYNYLDWYLQKPGQSPQLLIYLG-----SNRASGVPDRFSGSG--SGTDFTLKISRVEAEDVGVYYCMQALQTP----",
          "IGKV2-29*01": "DIVMTQTPLSLSVTPGQPASISCKSSQSLLHS-DGKTYLYWYLQKPGQSPQLLIYEV-----SSRFSGVPDRFSGSG--SGTDFTLKISRVEAEDVGVYY-MQGIHLP----",
          "IGKV2-29*02": "DIVMTQTPLSLSVTPGQPASISCKSSQSLLHS-DGKTYLYWYLQKPGQSPQLLIYEV-----SSRFSGVPDRFSGSG--SGTDFTLKISRVEAEDVGVYYCMQGIHLP----",
          "IGKV2-29*03": "DIVMTQTPLSLSVTPGQPASISCKSSQSLLHS-DGKTYLYWYLQKPGQSPQLLIYEV-----SSRFSGVPDRFSGSG--SGTDFTLKISRVEAEDVGVYYCMQGIHLP----",
          "IGKV2-30*01": "DVVMTQSPLSLPVTLGQPASISCRSSQSLVYS-DGNTYLNWFQQRPGQSPRRLIYKV-----SNRDSGVPDRFSGSG--SGTDFTLKISRVEAEDVGVYYCMQGTHWP----",
          "IGKV2-30*02": "DVVMTQSPLSLPVTLGQPASISCRSSQSLVHS-DGNTYLNWFQQRPGQSPRRLIYKV-----SNRDSGVPDRFSGSG--SGTDFTLKISRVEAEDVGVYYCMQGTHWP----",
          "IGKV2-4*01": "DIVMTQHLLSLPIPLGEPASISCRSSQSLLHS-DGNTYLDWYLQKPGQSPQLLIYTI-----SNKFYGVPNKFSGSR--SGTGFTLKFSKVEAEDVGVYCCEQGLQGP----",
          "IGKV2-40*01": "DIVMTQTPLSLPVTPGEPASISCRSSQSLLDSDDGNTYLDWYLQKPGQSPQLLIYTL-----SYRASGVPDRFSGSG--SGTDFTLKISRVEAEDVGVYYCMQRIEFP----",
          "IGKV2/OR2-7D*01": "DILLTQTPLSLSITPGEPASISCRSSRSLLHS-NGNTYLHW-LQKPGQPPQCLICKV-----SNRFSGVPDRFSGSG--SGIDFTLKISPVEAADVGVYITACKLHTGP---",
          "IGKV2/OR22-4*01": "DIVMTQTPLSLPVTPGEPASISCRSSESLLDTDDEYTYLNWYLQKPGQSPQLLIYEV-----SNRASGVPDRFSGSG--SGTDFTLKISRVEA-DVGVYYCMQALQTP----",
          "IGKV2D-18*01": "DIVMTQTPPSLPVNPGEPASISCRSSQSLLHS-NGYTYLHWYPQKPGQSPQLLIYRV-----SSRFSGVPDRFSGSG--SGSDFTLKISWVEAEDVGVYYCMQATQFP----",
          "IGKV2D-24*01": "DIVMTQTPLSSPVTLGQPASISFRSSQSLVHS-DGNTYLSWLQQRPGQPPRLLIYKV-----SNRFSGVPDRFSGSG--AGTDFTLKISRVEAEDVGVYYCTQATQFP----",
          "IGKV2D-26*01": "EIVMTQTPLSLSITPGEQASISCRSSQSLLHS-DGYTYLYWFLQKARPVSTLLIYEV-----SNRFSGVPDRFSGSG--SGTDFTLKISRVEAEDFGVYYCMQDAQDP----",
          "IGKV2D-26*02": "EIVMTQTPLSLSITPGEQASMSCRSSQSLLHS-DGYTYLYWFLQKARPVSTLLICEV-----SNRFSGVPDRFSGSG--SGTDFTLKISRVEAEDFGVYYCMQDAQDP----",
          "IGKV2D-26*03": "EIVMTQTPLSLSITPGEQASMSCRSSQSLLHS-DGYTYLYWFLQKARPVSTLLIYEV-----SNRFSGVPDRFSGSG--SGTDFTLKISRVEAEDFGVYYCMQDAQDP----",
          "IGKV2D-28*01": "DIVMTQSPLSLPVTPGEPASISCRSSQSLLHS-NGYNYLDWYLQKPGQSPQLLIYLG-----SNRASGVPDRFSGSG--SGTDFTLKISRVEAEDVGVYYCMQALQTP----",
          "IGKV2D-29*01": "DIVMTQTPLSLSVTPGQPASISCKSSQSLLHS-DGKTYLYWYLQKPGQPPQLLIYEV-----SNRFSGVPDRFSGSG--SGTDFTLKISRVEAEDVGVYYCMQSIQLP----",
          "IGKV2D-29*02": "DIVMTQTPLSLSVTPGQPASISCKSSQSLLHS-DGKTYLYWYLQKPGQSPQLLIYEV-----SNRFSGVPDRFSGSG--SGTDFTLKISRVEAEDVGVYYCMQSIQLP----",
          "IGKV2D-30*01": "DVVMTQSPLSLPVTLGQPASISCRSSQSLVYS-DGNTYLNWFQQRPGQSPRRLIYKV-----SNWDSGVPDRFSGSG--SGTDFTLKISRVEAEDVGVYYCMQGTHWP----",
          "IGKV2D-40*01": "DIVMTQTPLSLPVTPGEPASISCRSSQSLLDSDDGNTYLDWYLQKPGQSPQLLIYTL-----SYRASGVPDRFSGSG--SGTDFTLKISRVEAEDVGVYYCMQRIEFP----",
          "IGKV3-11*01": "EIVLTQSPATLSLSPGERATLSCRASQSV------SSYLAWYQQKPGQAPRLLIYDA-----SNRATGIPARFSGSG--SGTDFTLTISSLEPEDFAVYYCQQRSNWP----",
          "IGKV3-11*02": "EIVLTQSPATLSLSPGERATLSCRASQSV------SSYLAWYQQKPGQAPRLLIYDA-----SNRATGIPARFSGSG--SGRDFTLTISSLEPEDFAVYYCQQRSNWP----",
          "IGKV3-15*01": "EIVMTQSPATLSVSPGERATLSCRASQSV------SSNLAWYQQKPGQAPRLLIYGA-----STRATGIPARFSGSG--SGTEFTLTISSLQSEDFAVYYCQQYNNWP----",
          "IGKV3-20*01": "EIVLTQSPGTLSLSPGERATLSCRASQSVS-----SSYLAWYQQKPGQAPRLLIYGA-----SSRATGIPDRFSGSG--SGTDFTLTISRLEPEDFAVYYCQQYGSSP----",
          "IGKV3-7*01": "EIVMTQSPPTLSLSPGERVTLSCRASQSVS-----SSYLTWYQQKPGQAPRLLIYGA-----STRATSIPARFSGSG--SGTDFTLTISSLQPEDFAVYYCQQDHNLP----",
          "IGKV3-7*02": "EIVMTQSPPTLSLSPGERVTLSCRASQSVS-----SSYLSWYQQKPGQAPRLLIYGA-----STRATGIPARFSGSG--SGTDFTLTISSLQPEDFAVYYCQQDYNLP----",
          "IGKV3-7*03": "EIVMTQSPPTLSLSPGERVTLSCRASQSVS-----SSYLTWYQQKPGQAPRLLIYGA-----STRATSIPARFSGSG--SGRDFTLTISSLQPEDFAVYYCQQDHNLP----",
          "IGKV3-7*04": "EIVMTQSPPTLSLSPGERVTLSCRASQSVS-----SSYLTWYQQKPGQAPRLLIYGA-----STRATSIPARFSGSG--SGTDFTLTISSLQPEDFAVYYCQQDYNLP----",
          "IGKV3/OR2-268*01": "EIVMTQSPATLSLSPGERATLSCRASQSVS-----SSYLSWYQQKPGQAPRLLIYGA-----STRATGIPARFSGSG--SGTDFTLTISSLQPEDFAVYYCQQDYNLP----",
          "IGKV3/OR2-268*02": "EIVMTQSPATLSLSPGERATLSCRASQSVS-----SSYLSWYQQKPGQAPRLLIYGA-----STRATGIPARFSGSG--SGTDFTLTISSLQPEDFAVYYCQQDYNLP----",
          "IGKV3D-11*01": "EIVLTQSPATLSLSPGERATLSCRASQGV------SSYLAWYQQKPGQAPRLLIYDA-----SNRATGIPARFSGSG--PGTDFTLTISSLEPEDFAVYYCQQRSNWH----",
          "IGKV3D-11*02": "EIVLTQSPATLSLSPGERATLSCRASQSV------SSYLAWYQQKPGQAPRLLIYDA-----SNRATGIPARFSGSG--PGTDFTLTISSLEPEDFAVYYCQQRSNWH----",
          "IGKV3D-11*03": "EIVLTQSPATLSLSPGERATLSCRASQGV------SSNLAWYQQKPGQAPRLLIYDA-----SNRATGIPARFSGSG--PGTDFTLTISSLEPEDFAVYYCQQRSNWH----",
          "IGKV3D-15*01": "EIVMTQSPATLSVSPGERATLSCRASQSV------SSNLAWYQQKPGQAPRLLIYGA-----STRATGIPARFSGSG--SGTEFTLTISSLQSEDFAVYYCQQYNNWP----",
          "IGKV3D-15*02": "EIVMMQSPATLSVSPGERATLSCRASQSV------SSNLAWYQQKPGQAPRLLIYGA-----STRATGIPARFSGSG--SGTEFTLTISSLQSEDFAVYYCQQYNN-P----",
          "IGKV3D-15*03": "EIVMTQSPATLSVSPGERATLSCRASQSV------SSNLAWYQQKPGQAPRLLIYGA-----SIRATGIPARFSGSG--SGTEFTLTISILQSEDFAVYYCQQYNNWP----",
          "IGKV3D-20*01": "EIVLTQSPATLSLSPGERATLSCGASQSVS-----SSYLAWYQQKPGLAPRLLIYDA-----SSRATGIPDRFSGSG--SGTDFTLTISRLEPEDFAVYYCQQYGSSP----",
          "IGKV3D-20*02": "EIVLTQSPATLSLSPGERATLSCRASQSVS-----SSYLAWYQQKPGQAPRLLIYDA-----SSRATGIPDRFSGSG--SGTDFTLTISRLEPEDFAVYYCQQRSNWH----",
          "IGKV3D-7*01": "EIVMTQSPATLSLSPGERATLSCRASQSVS-----SSYLSWYQQKPGQAPRLLIYGA-----STRATGIPARFSGSG--SGTDFTLTISSLQPEDFAVYYCQQDYNLP----",
          "IGKV4-1*01": "DIVMTQSPDSLAVSLGERATINCKSSQSVLYSSNNKNYLAWYQQKPGQPPKLLIYWA-----STRESGVPDRFSGSG--SGTDFTLTISSLQAEDVAVYYCQQYYSTP----",
          "IGKV5-2*01": "ETTLTQSPAFMSATPGDKVNISCKASQDI------DDDMNWYQQKPGEAAIFIIQEA-----TTLVPGIPPRFSGSG--YGTDFTLTINNIESEDAAYYFCLQHDNFP----",
          "IGKV6-21*01": "EIVLTQSPDFQSVTPKEKVTITCRASQSI------GSSLHWYQQKPDQSPKLLIKYA-----SQSFSGVPSRFSGSG--SGTDFTLTINSLEAEDAATYYCHQSSSLP----",
          "IGKV6-21*02": "EIVLTQSPDFQSVTPKEKVTITCRASQSI------GSSLHWYQQKPDQSPKLLIKYA-----SQSISGVPSRFSGSG--SGTDFTLTINSLEAEDAATYYCHQSSSLP----",
          "IGKV6D-21*01": "EIVLTQSPDFQSVTPKEKVTITCRASQSI------GSSLHWYQQKPDQSPKLLIKYA-----SQSFSGVPSRFSGSG--SGTDFTLTINSLEAEDAATYYCHQSSSLP----",
          "IGKV6D-21*02": "EIVLTQSPDFQSVTPKEKVTITCRASQSI------GSSLHWYQQKPDQSPKLLIKYA-----SQSISGVPSRFSGSG--SGTDFTLTINSLEAEDAAAYYCHQSSSLP----",
          "IGKV6D-41*01": "DVVMTQSPAFLSVTPGEKVTITCQASEGI------GNYLYWYQQKPDQAPKLLIKYA-----SQSISGVPSRFSGSG--SGTDFTFTISSLEAEDAATYYCQQGNKHP----",
          "IGKV7-3*01": "DIVLTQSPASLAVSPGQRATITCRASESVSF--LGINLIHWYQQKPGQPPKLLIYQA-----SNKDTGVPARFSGSG--SGTDFTLTINPVEANDTANYYCLQSKNFP----"
        }
    }
}

HUMAN_IMGT_IG_J = {
    'H': {
        "positions": [
            "H112C", "H112B", "H112A", "H112", "H113", "H114", "H115", "H116", "H117", "H118", "H119", "H120", "H121", "H122", "H123", "H124", "H125", "H126", "H127", "H128"
        ],
        "aligned_sequences": {
            "IGHJ1*01": "---AEYFQHWGQGTLVTVSS",
            "IGHJ2*01": "---YWYFDLWGRGTLVTVSS",
            "IGHJ3*01": "----DAFDVWGQGTMVTVSS",
            "IGHJ3*02": "----DAFDIWGQGTMVTVSS",
            "IGHJ4*01": "-----YFDYWGQGTLVTVSS",
            "IGHJ4*02": "-----YFDYWGQGTLVTVSS",
            "IGHJ4*03": "-----YFDYWGQGTLVTVSS",
            "IGHJ5*01": "----NWFDSWGQGTLVTVSS",
            "IGHJ5*02": "----NWFDPWGQGTLVTVSS",
            "IGHJ6*01": "YYYYYGMDVWGQGTTVTVSS",
            "IGHJ6*04": "YYYYYGMDVWGKGTTVTVSS"
        }
    },
    'L': {
        "positions": [
            "L116", "L117", "L118", "L119", "L120", "L121", "L122", "L123", "L124", "L125", "L126", "L127"
        ],
        "aligned_sequences": {
            "IGLJ1*01": "YVFGTGTKVTVL",
            "IGLJ2*01": "VVFGGGTKLTVL",
            "IGLJ3*01": "VVFGGGTKLTVL",
            "IGLJ3*02": "WVFGGGTKLTVL",
            "IGLJ4*01": "FVFGGGTQLIIL",
            "IGLJ5*01": "WVFGEGTELTVL",
            "IGLJ5*02": "WVFGEGTELTVL",
            "IGLJ6*01": "NVFGSGTKVTVL",
            "IGLJ7*01": "AVFGGGTQLTVL",
            "IGLJ7*02": "AVFGGGTQLTAL"
        }
    },
    'K': {
        "positions": [
            "L116", "L117", "L118", "L119", "L120", "L121", "L122", "L123", "L124", "L125", "L126", "L127"
        ],
        "aligned_sequences": {
            "IGKJ1*01": "WTFGQGTKVEIK",
            "IGKJ2*01": "YTFGQGTKLEIK",
            "IGKJ2*02": "CTFGQGTKLEIK",
            "IGKJ2*03": "YSFGQGTKLEIK",
            "IGKJ2*04": "CSFGQGTKLEIK",
            "IGKJ3*01": "FTFGPGTKVDIK",
            "IGKJ4*01": "LTFGGGTKVEIK",
            "IGKJ4*02": "LTFGGGTKVEIK",
            "IGKJ5*01": "ITFGQGTRLEIK"
        }
    }
}